# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from .. import _utilities, _tables

__all__ = [
    'address',
    'http_proxy',
    'token',
]

__config__ = pulumi.Config('wavefront')

address = __config__.get('address') or _utilities.get_env('WAVEFRONT_ADDRESS')

http_proxy = __config__.get('httpProxy')

token = __config__.get('token') or _utilities.get_env('WAVEFRONT_TOKEN')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables
from . import outputs
from ._inputs import *

__all__ = ['AlertTarget']


class AlertTarget(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content_type: Optional[pulumi.Input[str]] = None,
                 custom_headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 email_subject: Optional[pulumi.Input[str]] = None,
                 is_html_content: Optional[pulumi.Input[bool]] = None,
                 method: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 recipient: Optional[pulumi.Input[str]] = None,
                 routes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertTargetRouteArgs']]]]] = None,
                 template: Optional[pulumi.Input[str]] = None,
                 triggers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Provides a wavefront Alert Target resource. This allows alert targets to created, updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        test_target = wavefront.AlertTarget("testTarget",
            content_type="application/json",
            custom_headers={
                "Testing": "true",
            },
            description="Test target",
            method="WEBHOOK",
            recipient="https://hooks.slack.com/services/test/me",
            template="{}",
            triggers=[
                "ALERT_OPENED",
                "ALERT_RESOLVED",
            ])
        ```
        ## Attributes Reference

        * `target_id` - The target ID prefixed with `target:` for interpolating into a Wavefront Alert.

        ### Route

        The `route` mapping supports the following:

        * `method` - (Required)  The notification method used for notification target. One of `WEBHOOK`, `EMAIL`, `PAGERDUTY`.
        * `target` - (Required) The endpoint for the alert route. `EMAIL`: email address. `PAGERDUTY`: PagerDuty routing
          key. `WEBHOOK`: URL endpoint.
        * `filter` - (Required) String that filters the route. Space delimited.  Currently only allows a single key value pair.
          (e.g. `env prod`)

        ### Example

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        test_target = wavefront.AlertTarget("testTarget",
            content_type="application/json",
            custom_headers={
                "Testing": "true",
            },
            description="Test target",
            method="WEBHOOK",
            recipient="https://hooks.slack.com/services/test/me",
            routes=[
                wavefront.AlertTargetRouteArgs(
                    filter={
                        "key": "env",
                        "value": "prod",
                    },
                    method="WEBHOOK",
                    target="https://hooks.slack.com/services/test/me/prod",
                ),
                wavefront.AlertTargetRouteArgs(
                    filter={
                        "key": "env",
                        "value": "dev",
                    },
                    method="WEBHOOK",
                    target="https://hooks.slack.com/services/test/me/dev",
                ),
            ],
            template="{}",
            triggers=[
                "ALERT_OPENED",
                "ALERT_RESOLVED",
            ])
        ```

        ## Import

        Alert Targets can be imported using the `id`, e.g.

        ```sh
         $ pulumi import wavefront:index/alertTarget:AlertTarget alert_target abcdEFGhijKLMNO
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] content_type: The value of the `Content-Type` header of the webhook.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] custom_headers: A `string->string` map specifying the custome HTTP header key/value pairs that will be 
               sent in the requests with a method of `WEBHOOK`.
        :param pulumi.Input[str] description: Description describing this alert target.
        :param pulumi.Input[str] email_subject: The subject title of an email notification target.
        :param pulumi.Input[bool] is_html_content: Determine whether the email alert content is sent as HTML or text.
        :param pulumi.Input[str] method: The notification method used for notification target. One of `WEBHOOK`, `EMAIL`, `PAGERDUTY`.
        :param pulumi.Input[str] name: The name of the alert target as it is displayed in wavefront
        :param pulumi.Input[str] recipient: The end point for the notification Target.  `EMAIL`: email address. `PAGERDUTY`: PagerDuty 
               routing key. `WEBHOOK`: URL endpoint.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertTargetRouteArgs']]]] routes: List of routing targets that this alert target will notify. See Route
        :param pulumi.Input[str] template: A mustache template that will form the body of the POST request, email and summary of the PagerDuty.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] triggers: A list of occurrences on which this webhook will be fired. Valid values are `ALERT_OPENED`,
               `ALERT_UPDATED`, `ALERT_RESOLVED`, `ALERT_MAINTENANCE`, `ALERT_SNOOZED`, `ALERT_NO_DATA`, `ALERT_NO_DATA_RESOLVED`, `ALERT_NO_DATA_MAINTENANCE`.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['content_type'] = content_type
            __props__['custom_headers'] = custom_headers
            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__['description'] = description
            __props__['email_subject'] = email_subject
            __props__['is_html_content'] = is_html_content
            __props__['method'] = method
            __props__['name'] = name
            if recipient is None and not opts.urn:
                raise TypeError("Missing required property 'recipient'")
            __props__['recipient'] = recipient
            __props__['routes'] = routes
            if template is None and not opts.urn:
                raise TypeError("Missing required property 'template'")
            __props__['template'] = template
            if triggers is None and not opts.urn:
                raise TypeError("Missing required property 'triggers'")
            __props__['triggers'] = triggers
            __props__['target_id'] = None
        super(AlertTarget, __self__).__init__(
            'wavefront:index/alertTarget:AlertTarget',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            content_type: Optional[pulumi.Input[str]] = None,
            custom_headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            description: Optional[pulumi.Input[str]] = None,
            email_subject: Optional[pulumi.Input[str]] = None,
            is_html_content: Optional[pulumi.Input[bool]] = None,
            method: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            recipient: Optional[pulumi.Input[str]] = None,
            routes: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertTargetRouteArgs']]]]] = None,
            target_id: Optional[pulumi.Input[str]] = None,
            template: Optional[pulumi.Input[str]] = None,
            triggers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'AlertTarget':
        """
        Get an existing AlertTarget resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] content_type: The value of the `Content-Type` header of the webhook.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] custom_headers: A `string->string` map specifying the custome HTTP header key/value pairs that will be 
               sent in the requests with a method of `WEBHOOK`.
        :param pulumi.Input[str] description: Description describing this alert target.
        :param pulumi.Input[str] email_subject: The subject title of an email notification target.
        :param pulumi.Input[bool] is_html_content: Determine whether the email alert content is sent as HTML or text.
        :param pulumi.Input[str] method: The notification method used for notification target. One of `WEBHOOK`, `EMAIL`, `PAGERDUTY`.
        :param pulumi.Input[str] name: The name of the alert target as it is displayed in wavefront
        :param pulumi.Input[str] recipient: The end point for the notification Target.  `EMAIL`: email address. `PAGERDUTY`: PagerDuty 
               routing key. `WEBHOOK`: URL endpoint.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AlertTargetRouteArgs']]]] routes: List of routing targets that this alert target will notify. See Route
        :param pulumi.Input[str] template: A mustache template that will form the body of the POST request, email and summary of the PagerDuty.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] triggers: A list of occurrences on which this webhook will be fired. Valid values are `ALERT_OPENED`,
               `ALERT_UPDATED`, `ALERT_RESOLVED`, `ALERT_MAINTENANCE`, `ALERT_SNOOZED`, `ALERT_NO_DATA`, `ALERT_NO_DATA_RESOLVED`, `ALERT_NO_DATA_MAINTENANCE`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["content_type"] = content_type
        __props__["custom_headers"] = custom_headers
        __props__["description"] = description
        __props__["email_subject"] = email_subject
        __props__["is_html_content"] = is_html_content
        __props__["method"] = method
        __props__["name"] = name
        __props__["recipient"] = recipient
        __props__["routes"] = routes
        __props__["target_id"] = target_id
        __props__["template"] = template
        __props__["triggers"] = triggers
        return AlertTarget(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="contentType")
    def content_type(self) -> pulumi.Output[Optional[str]]:
        """
        The value of the `Content-Type` header of the webhook.
        """
        return pulumi.get(self, "content_type")

    @property
    @pulumi.getter(name="customHeaders")
    def custom_headers(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A `string->string` map specifying the custome HTTP header key/value pairs that will be 
        sent in the requests with a method of `WEBHOOK`.
        """
        return pulumi.get(self, "custom_headers")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Description describing this alert target.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="emailSubject")
    def email_subject(self) -> pulumi.Output[Optional[str]]:
        """
        The subject title of an email notification target.
        """
        return pulumi.get(self, "email_subject")

    @property
    @pulumi.getter(name="isHtmlContent")
    def is_html_content(self) -> pulumi.Output[Optional[bool]]:
        """
        Determine whether the email alert content is sent as HTML or text.
        """
        return pulumi.get(self, "is_html_content")

    @property
    @pulumi.getter
    def method(self) -> pulumi.Output[Optional[str]]:
        """
        The notification method used for notification target. One of `WEBHOOK`, `EMAIL`, `PAGERDUTY`.
        """
        return pulumi.get(self, "method")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the alert target as it is displayed in wavefront
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def recipient(self) -> pulumi.Output[str]:
        """
        The end point for the notification Target.  `EMAIL`: email address. `PAGERDUTY`: PagerDuty 
        routing key. `WEBHOOK`: URL endpoint.
        """
        return pulumi.get(self, "recipient")

    @property
    @pulumi.getter
    def routes(self) -> pulumi.Output[Optional[Sequence['outputs.AlertTargetRoute']]]:
        """
        List of routing targets that this alert target will notify. See Route
        """
        return pulumi.get(self, "routes")

    @property
    @pulumi.getter(name="targetId")
    def target_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "target_id")

    @property
    @pulumi.getter
    def template(self) -> pulumi.Output[str]:
        """
        A mustache template that will form the body of the POST request, email and summary of the PagerDuty.
        """
        return pulumi.get(self, "template")

    @property
    @pulumi.getter
    def triggers(self) -> pulumi.Output[Sequence[str]]:
        """
        A list of occurrences on which this webhook will be fired. Valid values are `ALERT_OPENED`,
        `ALERT_UPDATED`, `ALERT_RESOLVED`, `ALERT_MAINTENANCE`, `ALERT_SNOOZED`, `ALERT_NO_DATA`, `ALERT_NO_DATA_RESOLVED`, `ALERT_NO_DATA_MAINTENANCE`.
        """
        return pulumi.get(self, "triggers")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables

__all__ = ['CloudIntegrationAppDynamics']


class CloudIntegrationAppDynamics(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 app_filter_regexes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 controller_name: Optional[pulumi.Input[str]] = None,
                 enable_app_infra_metrics: Optional[pulumi.Input[bool]] = None,
                 enable_backend_metrics: Optional[pulumi.Input[bool]] = None,
                 enable_business_trx_metrics: Optional[pulumi.Input[bool]] = None,
                 enable_error_metrics: Optional[pulumi.Input[bool]] = None,
                 enable_individual_node_metrics: Optional[pulumi.Input[bool]] = None,
                 enable_overall_perf_metrics: Optional[pulumi.Input[bool]] = None,
                 enable_rollup: Optional[pulumi.Input[bool]] = None,
                 enable_service_endpoint_metrics: Optional[pulumi.Input[bool]] = None,
                 encrypted_password: Optional[pulumi.Input[str]] = None,
                 force_save: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 service: Optional[pulumi.Input[str]] = None,
                 service_refresh_rate_in_minutes: Optional[pulumi.Input[int]] = None,
                 user_name: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Provides a Wavefront Cloud Integration for App Dynamics. This allows app dynamics cloud integrations to be created,
        updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        app_dynamics = wavefront.CloudIntegrationAppDynamics("appDynamics",
            controller_name="exampleController",
            encrypted_password="encryptedPassword",
            user_name="example")
        ```

        ## Import

        App Dynamic Cloud Integrations can be imported using the `id`, e.g.

        ```sh
         $ pulumi import wavefront:index/cloudIntegrationAppDynamics:CloudIntegrationAppDynamics app_dynamics a411c16b-3cf7-4f03-bf11-8ca05aab898d
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] additional_tags: A list of point tag key-values to add to every point ingested using this integration
        :param pulumi.Input[Sequence[pulumi.Input[str]]] app_filter_regexes: List of regular expressions that a application name must match (case-insensitively) 
               in order to be ingested
        :param pulumi.Input[str] controller_name: Name of the SaaS controller
        :param pulumi.Input[bool] enable_app_infra_metrics: Boolean flag to control Application Infrastructure metric injection
        :param pulumi.Input[bool] enable_backend_metrics: Boolean flag to control Backend metric injection
        :param pulumi.Input[bool] enable_business_trx_metrics: Boolean flag to control Business Transaction metric injection
        :param pulumi.Input[bool] enable_error_metrics: Boolean flag to control Error metric injection
        :param pulumi.Input[bool] enable_individual_node_metrics: Boolean flag to control Individual Node metric injection
        :param pulumi.Input[bool] enable_overall_perf_metrics: Boolean flag to control Overall Performance metric injection
        :param pulumi.Input[bool] enable_rollup: Set this to `false` to get separate results for all values within the time range, 
               by default it is `true`
        :param pulumi.Input[bool] enable_service_endpoint_metrics: Boolean flag to control Service End point metric injection
        :param pulumi.Input[str] encrypted_password: Password for AppDynamics user
        :param pulumi.Input[bool] force_save: Forces this resource to save, even if errors are present
        :param pulumi.Input[str] name: The human-readable name of this integration
        :param pulumi.Input[str] service: A value denoting which cloud service this service integrates with
        :param pulumi.Input[int] service_refresh_rate_in_minutes: How often, in minutes, to refresh the service
        :param pulumi.Input[str] user_name: Username is a combination of userName and the account name
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['additional_tags'] = additional_tags
            __props__['app_filter_regexes'] = app_filter_regexes
            if controller_name is None and not opts.urn:
                raise TypeError("Missing required property 'controller_name'")
            __props__['controller_name'] = controller_name
            __props__['enable_app_infra_metrics'] = enable_app_infra_metrics
            __props__['enable_backend_metrics'] = enable_backend_metrics
            __props__['enable_business_trx_metrics'] = enable_business_trx_metrics
            __props__['enable_error_metrics'] = enable_error_metrics
            __props__['enable_individual_node_metrics'] = enable_individual_node_metrics
            __props__['enable_overall_perf_metrics'] = enable_overall_perf_metrics
            __props__['enable_rollup'] = enable_rollup
            __props__['enable_service_endpoint_metrics'] = enable_service_endpoint_metrics
            if encrypted_password is None and not opts.urn:
                raise TypeError("Missing required property 'encrypted_password'")
            __props__['encrypted_password'] = encrypted_password
            __props__['force_save'] = force_save
            __props__['name'] = name
            if service is None and not opts.urn:
                raise TypeError("Missing required property 'service'")
            __props__['service'] = service
            __props__['service_refresh_rate_in_minutes'] = service_refresh_rate_in_minutes
            if user_name is None and not opts.urn:
                raise TypeError("Missing required property 'user_name'")
            __props__['user_name'] = user_name
        super(CloudIntegrationAppDynamics, __self__).__init__(
            'wavefront:index/cloudIntegrationAppDynamics:CloudIntegrationAppDynamics',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            additional_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            app_filter_regexes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            controller_name: Optional[pulumi.Input[str]] = None,
            enable_app_infra_metrics: Optional[pulumi.Input[bool]] = None,
            enable_backend_metrics: Optional[pulumi.Input[bool]] = None,
            enable_business_trx_metrics: Optional[pulumi.Input[bool]] = None,
            enable_error_metrics: Optional[pulumi.Input[bool]] = None,
            enable_individual_node_metrics: Optional[pulumi.Input[bool]] = None,
            enable_overall_perf_metrics: Optional[pulumi.Input[bool]] = None,
            enable_rollup: Optional[pulumi.Input[bool]] = None,
            enable_service_endpoint_metrics: Optional[pulumi.Input[bool]] = None,
            encrypted_password: Optional[pulumi.Input[str]] = None,
            force_save: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            service: Optional[pulumi.Input[str]] = None,
            service_refresh_rate_in_minutes: Optional[pulumi.Input[int]] = None,
            user_name: Optional[pulumi.Input[str]] = None) -> 'CloudIntegrationAppDynamics':
        """
        Get an existing CloudIntegrationAppDynamics resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] additional_tags: A list of point tag key-values to add to every point ingested using this integration
        :param pulumi.Input[Sequence[pulumi.Input[str]]] app_filter_regexes: List of regular expressions that a application name must match (case-insensitively) 
               in order to be ingested
        :param pulumi.Input[str] controller_name: Name of the SaaS controller
        :param pulumi.Input[bool] enable_app_infra_metrics: Boolean flag to control Application Infrastructure metric injection
        :param pulumi.Input[bool] enable_backend_metrics: Boolean flag to control Backend metric injection
        :param pulumi.Input[bool] enable_business_trx_metrics: Boolean flag to control Business Transaction metric injection
        :param pulumi.Input[bool] enable_error_metrics: Boolean flag to control Error metric injection
        :param pulumi.Input[bool] enable_individual_node_metrics: Boolean flag to control Individual Node metric injection
        :param pulumi.Input[bool] enable_overall_perf_metrics: Boolean flag to control Overall Performance metric injection
        :param pulumi.Input[bool] enable_rollup: Set this to `false` to get separate results for all values within the time range, 
               by default it is `true`
        :param pulumi.Input[bool] enable_service_endpoint_metrics: Boolean flag to control Service End point metric injection
        :param pulumi.Input[str] encrypted_password: Password for AppDynamics user
        :param pulumi.Input[bool] force_save: Forces this resource to save, even if errors are present
        :param pulumi.Input[str] name: The human-readable name of this integration
        :param pulumi.Input[str] service: A value denoting which cloud service this service integrates with
        :param pulumi.Input[int] service_refresh_rate_in_minutes: How often, in minutes, to refresh the service
        :param pulumi.Input[str] user_name: Username is a combination of userName and the account name
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["additional_tags"] = additional_tags
        __props__["app_filter_regexes"] = app_filter_regexes
        __props__["controller_name"] = controller_name
        __props__["enable_app_infra_metrics"] = enable_app_infra_metrics
        __props__["enable_backend_metrics"] = enable_backend_metrics
        __props__["enable_business_trx_metrics"] = enable_business_trx_metrics
        __props__["enable_error_metrics"] = enable_error_metrics
        __props__["enable_individual_node_metrics"] = enable_individual_node_metrics
        __props__["enable_overall_perf_metrics"] = enable_overall_perf_metrics
        __props__["enable_rollup"] = enable_rollup
        __props__["enable_service_endpoint_metrics"] = enable_service_endpoint_metrics
        __props__["encrypted_password"] = encrypted_password
        __props__["force_save"] = force_save
        __props__["name"] = name
        __props__["service"] = service
        __props__["service_refresh_rate_in_minutes"] = service_refresh_rate_in_minutes
        __props__["user_name"] = user_name
        return CloudIntegrationAppDynamics(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="additionalTags")
    def additional_tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A list of point tag key-values to add to every point ingested using this integration
        """
        return pulumi.get(self, "additional_tags")

    @property
    @pulumi.getter(name="appFilterRegexes")
    def app_filter_regexes(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of regular expressions that a application name must match (case-insensitively) 
        in order to be ingested
        """
        return pulumi.get(self, "app_filter_regexes")

    @property
    @pulumi.getter(name="controllerName")
    def controller_name(self) -> pulumi.Output[str]:
        """
        Name of the SaaS controller
        """
        return pulumi.get(self, "controller_name")

    @property
    @pulumi.getter(name="enableAppInfraMetrics")
    def enable_app_infra_metrics(self) -> pulumi.Output[Optional[bool]]:
        """
        Boolean flag to control Application Infrastructure metric injection
        """
        return pulumi.get(self, "enable_app_infra_metrics")

    @property
    @pulumi.getter(name="enableBackendMetrics")
    def enable_backend_metrics(self) -> pulumi.Output[Optional[bool]]:
        """
        Boolean flag to control Backend metric injection
        """
        return pulumi.get(self, "enable_backend_metrics")

    @property
    @pulumi.getter(name="enableBusinessTrxMetrics")
    def enable_business_trx_metrics(self) -> pulumi.Output[Optional[bool]]:
        """
        Boolean flag to control Business Transaction metric injection
        """
        return pulumi.get(self, "enable_business_trx_metrics")

    @property
    @pulumi.getter(name="enableErrorMetrics")
    def enable_error_metrics(self) -> pulumi.Output[Optional[bool]]:
        """
        Boolean flag to control Error metric injection
        """
        return pulumi.get(self, "enable_error_metrics")

    @property
    @pulumi.getter(name="enableIndividualNodeMetrics")
    def enable_individual_node_metrics(self) -> pulumi.Output[Optional[bool]]:
        """
        Boolean flag to control Individual Node metric injection
        """
        return pulumi.get(self, "enable_individual_node_metrics")

    @property
    @pulumi.getter(name="enableOverallPerfMetrics")
    def enable_overall_perf_metrics(self) -> pulumi.Output[Optional[bool]]:
        """
        Boolean flag to control Overall Performance metric injection
        """
        return pulumi.get(self, "enable_overall_perf_metrics")

    @property
    @pulumi.getter(name="enableRollup")
    def enable_rollup(self) -> pulumi.Output[Optional[bool]]:
        """
        Set this to `false` to get separate results for all values within the time range, 
        by default it is `true`
        """
        return pulumi.get(self, "enable_rollup")

    @property
    @pulumi.getter(name="enableServiceEndpointMetrics")
    def enable_service_endpoint_metrics(self) -> pulumi.Output[Optional[bool]]:
        """
        Boolean flag to control Service End point metric injection
        """
        return pulumi.get(self, "enable_service_endpoint_metrics")

    @property
    @pulumi.getter(name="encryptedPassword")
    def encrypted_password(self) -> pulumi.Output[str]:
        """
        Password for AppDynamics user
        """
        return pulumi.get(self, "encrypted_password")

    @property
    @pulumi.getter(name="forceSave")
    def force_save(self) -> pulumi.Output[Optional[bool]]:
        """
        Forces this resource to save, even if errors are present
        """
        return pulumi.get(self, "force_save")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The human-readable name of this integration
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def service(self) -> pulumi.Output[str]:
        """
        A value denoting which cloud service this service integrates with
        """
        return pulumi.get(self, "service")

    @property
    @pulumi.getter(name="serviceRefreshRateInMinutes")
    def service_refresh_rate_in_minutes(self) -> pulumi.Output[Optional[int]]:
        """
        How often, in minutes, to refresh the service
        """
        return pulumi.get(self, "service_refresh_rate_in_minutes")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Output[str]:
        """
        Username is a combination of userName and the account name
        """
        return pulumi.get(self, "user_name")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables

__all__ = ['CloudIntegrationAzureActivityLog']


class CloudIntegrationAzureActivityLog(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 category_filters: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 client_id: Optional[pulumi.Input[str]] = None,
                 client_secret: Optional[pulumi.Input[str]] = None,
                 force_save: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 service: Optional[pulumi.Input[str]] = None,
                 service_refresh_rate_in_minutes: Optional[pulumi.Input[int]] = None,
                 tenant: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Provides a Wavefront Cloud Integration for Azure Activity Logs. This allows azure activity log cloud integrations to be created,
        updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        azure_activity_log = wavefront.CloudIntegrationAzureActivityLog("azureActivityLog",
            category_filters=["ADMINISTRATIVE"],
            client_id="client-id2",
            client_secret="client-secret2",
            tenant="my-tenant2")
        ```

        ## Import

        Azure Activity Log Cloud Integrations can be imported using the `id`, e.g.

        ```sh
         $ pulumi import wavefront:index/cloudIntegrationAzureActivityLog:CloudIntegrationAzureActivityLog azure_al a411c16b-3cf7-4f03-bf11-8ca05aab898d
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] additional_tags: A list of point tag key-values to add to every point ingested using this integration
        :param pulumi.Input[Sequence[pulumi.Input[str]]] category_filters: A list of Azure services (such as Microsoft.Compute/virtualMachines) from which to pull metrics
        :param pulumi.Input[str] client_id: Client id for an azure service account within your project
        :param pulumi.Input[str] client_secret: Client secret for an Azure service account within your project
        :param pulumi.Input[bool] force_save: Forces this resource to save, even if errors are present
        :param pulumi.Input[str] name: The human-readable name of this integration
        :param pulumi.Input[str] service: A value denoting which cloud service this service integrates with
        :param pulumi.Input[int] service_refresh_rate_in_minutes: How often, in minutes, to refresh the service
        :param pulumi.Input[str] tenant: Tenant Id for an Azure service account within your project
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['additional_tags'] = additional_tags
            __props__['category_filters'] = category_filters
            if client_id is None and not opts.urn:
                raise TypeError("Missing required property 'client_id'")
            __props__['client_id'] = client_id
            if client_secret is None and not opts.urn:
                raise TypeError("Missing required property 'client_secret'")
            __props__['client_secret'] = client_secret
            __props__['force_save'] = force_save
            __props__['name'] = name
            if service is None and not opts.urn:
                raise TypeError("Missing required property 'service'")
            __props__['service'] = service
            __props__['service_refresh_rate_in_minutes'] = service_refresh_rate_in_minutes
            if tenant is None and not opts.urn:
                raise TypeError("Missing required property 'tenant'")
            __props__['tenant'] = tenant
        super(CloudIntegrationAzureActivityLog, __self__).__init__(
            'wavefront:index/cloudIntegrationAzureActivityLog:CloudIntegrationAzureActivityLog',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            additional_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            category_filters: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            client_id: Optional[pulumi.Input[str]] = None,
            client_secret: Optional[pulumi.Input[str]] = None,
            force_save: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            service: Optional[pulumi.Input[str]] = None,
            service_refresh_rate_in_minutes: Optional[pulumi.Input[int]] = None,
            tenant: Optional[pulumi.Input[str]] = None) -> 'CloudIntegrationAzureActivityLog':
        """
        Get an existing CloudIntegrationAzureActivityLog resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] additional_tags: A list of point tag key-values to add to every point ingested using this integration
        :param pulumi.Input[Sequence[pulumi.Input[str]]] category_filters: A list of Azure services (such as Microsoft.Compute/virtualMachines) from which to pull metrics
        :param pulumi.Input[str] client_id: Client id for an azure service account within your project
        :param pulumi.Input[str] client_secret: Client secret for an Azure service account within your project
        :param pulumi.Input[bool] force_save: Forces this resource to save, even if errors are present
        :param pulumi.Input[str] name: The human-readable name of this integration
        :param pulumi.Input[str] service: A value denoting which cloud service this service integrates with
        :param pulumi.Input[int] service_refresh_rate_in_minutes: How often, in minutes, to refresh the service
        :param pulumi.Input[str] tenant: Tenant Id for an Azure service account within your project
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["additional_tags"] = additional_tags
        __props__["category_filters"] = category_filters
        __props__["client_id"] = client_id
        __props__["client_secret"] = client_secret
        __props__["force_save"] = force_save
        __props__["name"] = name
        __props__["service"] = service
        __props__["service_refresh_rate_in_minutes"] = service_refresh_rate_in_minutes
        __props__["tenant"] = tenant
        return CloudIntegrationAzureActivityLog(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="additionalTags")
    def additional_tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A list of point tag key-values to add to every point ingested using this integration
        """
        return pulumi.get(self, "additional_tags")

    @property
    @pulumi.getter(name="categoryFilters")
    def category_filters(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of Azure services (such as Microsoft.Compute/virtualMachines) from which to pull metrics
        """
        return pulumi.get(self, "category_filters")

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Output[str]:
        """
        Client id for an azure service account within your project
        """
        return pulumi.get(self, "client_id")

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> pulumi.Output[str]:
        """
        Client secret for an Azure service account within your project
        """
        return pulumi.get(self, "client_secret")

    @property
    @pulumi.getter(name="forceSave")
    def force_save(self) -> pulumi.Output[Optional[bool]]:
        """
        Forces this resource to save, even if errors are present
        """
        return pulumi.get(self, "force_save")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The human-readable name of this integration
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def service(self) -> pulumi.Output[str]:
        """
        A value denoting which cloud service this service integrates with
        """
        return pulumi.get(self, "service")

    @property
    @pulumi.getter(name="serviceRefreshRateInMinutes")
    def service_refresh_rate_in_minutes(self) -> pulumi.Output[Optional[int]]:
        """
        How often, in minutes, to refresh the service
        """
        return pulumi.get(self, "service_refresh_rate_in_minutes")

    @property
    @pulumi.getter
    def tenant(self) -> pulumi.Output[str]:
        """
        Tenant Id for an Azure service account within your project
        """
        return pulumi.get(self, "tenant")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables

__all__ = ['CloudIntegrationGcp']


class CloudIntegrationGcp(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 categories: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 force_save: Optional[pulumi.Input[bool]] = None,
                 json_key: Optional[pulumi.Input[str]] = None,
                 metric_filter_regex: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 service: Optional[pulumi.Input[str]] = None,
                 service_refresh_rate_in_minutes: Optional[pulumi.Input[int]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Provides a Wavefront Cloud Integration for GCP. This allows GCP cloud integrations to be created,
        updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        gcp = wavefront.CloudIntegrationGcp("gcp",
            json_key=\"\"\"{...your gcp key ...}

        \"\"\",
            project_id="example-gcp-project")
        ```

        ## Import

        GCP Cloud Integrations can be imported using the `id`, e.g.

        ```sh
         $ pulumi import wavefront:index/cloudIntegrationGcp:CloudIntegrationGcp gcp a411c16b-3cf7-4f03-bf11-8ca05aab898d
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] additional_tags: A list of point tag key-values to add to every point ingested using this integration
        :param pulumi.Input[Sequence[pulumi.Input[str]]] categories: A list of Google Cloud Platform (GCP) services.  Valid values are `APPENGINE`, 
               `BIGQUERY`, `BIGTABLE`, `CLOUDFUNCTIONS`, `CLOUDIOT`, `CLOUDSQL`, `CLOUDTASKS`, `COMPUTE`, `CONTAINER`,
               `DATAFLOW`, `DATAPROC`, `DATASTORE`, `FIREBASEDATABASE`, `FIREBASEHOSTING`, `FIRESTORE`, `INTERCONNECT`,
               `LOADBALANCING`, `LOGGING`, `ML`, `MONITORING`, `PUBSUB`, `REDIS`, `ROUTER`, `SERVICERUNTIME`, `SPANNER`, `STORAGE`,
               `TPU`, `VPN`
        :param pulumi.Input[bool] force_save: Forces this resource to save, even if errors are present
        :param pulumi.Input[str] json_key: Private key for a Google Cloud Platform (GCP) service account within your project.
               The account must be at least granted Monitoring Viewer permissions. This key must be in the JSON format generated by GCP.
        :param pulumi.Input[str] metric_filter_regex: A regular expression that a metric name must match (case-insensitively) in order to be ingested
        :param pulumi.Input[str] name: The human-readable name of this integration
        :param pulumi.Input[str] project_id: The Google Cloud Platform (GCP) Project Id
        :param pulumi.Input[str] service: A value denoting which cloud service this service integrates with
        :param pulumi.Input[int] service_refresh_rate_in_minutes: How often, in minutes, to refresh the service
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['additional_tags'] = additional_tags
            __props__['categories'] = categories
            __props__['force_save'] = force_save
            if json_key is None and not opts.urn:
                raise TypeError("Missing required property 'json_key'")
            __props__['json_key'] = json_key
            __props__['metric_filter_regex'] = metric_filter_regex
            __props__['name'] = name
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__['project_id'] = project_id
            if service is None and not opts.urn:
                raise TypeError("Missing required property 'service'")
            __props__['service'] = service
            __props__['service_refresh_rate_in_minutes'] = service_refresh_rate_in_minutes
        super(CloudIntegrationGcp, __self__).__init__(
            'wavefront:index/cloudIntegrationGcp:CloudIntegrationGcp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            additional_tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            categories: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            force_save: Optional[pulumi.Input[bool]] = None,
            json_key: Optional[pulumi.Input[str]] = None,
            metric_filter_regex: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[str]] = None,
            service: Optional[pulumi.Input[str]] = None,
            service_refresh_rate_in_minutes: Optional[pulumi.Input[int]] = None) -> 'CloudIntegrationGcp':
        """
        Get an existing CloudIntegrationGcp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] additional_tags: A list of point tag key-values to add to every point ingested using this integration
        :param pulumi.Input[Sequence[pulumi.Input[str]]] categories: A list of Google Cloud Platform (GCP) services.  Valid values are `APPENGINE`, 
               `BIGQUERY`, `BIGTABLE`, `CLOUDFUNCTIONS`, `CLOUDIOT`, `CLOUDSQL`, `CLOUDTASKS`, `COMPUTE`, `CONTAINER`,
               `DATAFLOW`, `DATAPROC`, `DATASTORE`, `FIREBASEDATABASE`, `FIREBASEHOSTING`, `FIRESTORE`, `INTERCONNECT`,
               `LOADBALANCING`, `LOGGING`, `ML`, `MONITORING`, `PUBSUB`, `REDIS`, `ROUTER`, `SERVICERUNTIME`, `SPANNER`, `STORAGE`,
               `TPU`, `VPN`
        :param pulumi.Input[bool] force_save: Forces this resource to save, even if errors are present
        :param pulumi.Input[str] json_key: Private key for a Google Cloud Platform (GCP) service account within your project.
               The account must be at least granted Monitoring Viewer permissions. This key must be in the JSON format generated by GCP.
        :param pulumi.Input[str] metric_filter_regex: A regular expression that a metric name must match (case-insensitively) in order to be ingested
        :param pulumi.Input[str] name: The human-readable name of this integration
        :param pulumi.Input[str] project_id: The Google Cloud Platform (GCP) Project Id
        :param pulumi.Input[str] service: A value denoting which cloud service this service integrates with
        :param pulumi.Input[int] service_refresh_rate_in_minutes: How often, in minutes, to refresh the service
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["additional_tags"] = additional_tags
        __props__["categories"] = categories
        __props__["force_save"] = force_save
        __props__["json_key"] = json_key
        __props__["metric_filter_regex"] = metric_filter_regex
        __props__["name"] = name
        __props__["project_id"] = project_id
        __props__["service"] = service
        __props__["service_refresh_rate_in_minutes"] = service_refresh_rate_in_minutes
        return CloudIntegrationGcp(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="additionalTags")
    def additional_tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A list of point tag key-values to add to every point ingested using this integration
        """
        return pulumi.get(self, "additional_tags")

    @property
    @pulumi.getter
    def categories(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of Google Cloud Platform (GCP) services.  Valid values are `APPENGINE`, 
        `BIGQUERY`, `BIGTABLE`, `CLOUDFUNCTIONS`, `CLOUDIOT`, `CLOUDSQL`, `CLOUDTASKS`, `COMPUTE`, `CONTAINER`,
        `DATAFLOW`, `DATAPROC`, `DATASTORE`, `FIREBASEDATABASE`, `FIREBASEHOSTING`, `FIRESTORE`, `INTERCONNECT`,
        `LOADBALANCING`, `LOGGING`, `ML`, `MONITORING`, `PUBSUB`, `REDIS`, `ROUTER`, `SERVICERUNTIME`, `SPANNER`, `STORAGE`,
        `TPU`, `VPN`
        """
        return pulumi.get(self, "categories")

    @property
    @pulumi.getter(name="forceSave")
    def force_save(self) -> pulumi.Output[Optional[bool]]:
        """
        Forces this resource to save, even if errors are present
        """
        return pulumi.get(self, "force_save")

    @property
    @pulumi.getter(name="jsonKey")
    def json_key(self) -> pulumi.Output[str]:
        """
        Private key for a Google Cloud Platform (GCP) service account within your project.
        The account must be at least granted Monitoring Viewer permissions. This key must be in the JSON format generated by GCP.
        """
        return pulumi.get(self, "json_key")

    @property
    @pulumi.getter(name="metricFilterRegex")
    def metric_filter_regex(self) -> pulumi.Output[Optional[str]]:
        """
        A regular expression that a metric name must match (case-insensitively) in order to be ingested
        """
        return pulumi.get(self, "metric_filter_regex")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The human-readable name of this integration
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        """
        The Google Cloud Platform (GCP) Project Id
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def service(self) -> pulumi.Output[str]:
        """
        A value denoting which cloud service this service integrates with
        """
        return pulumi.get(self, "service")

    @property
    @pulumi.getter(name="serviceRefreshRateInMinutes")
    def service_refresh_rate_in_minutes(self) -> pulumi.Output[Optional[int]]:
        """
        How often, in minutes, to refresh the service
        """
        return pulumi.get(self, "service_refresh_rate_in_minutes")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables
from . import outputs
from ._inputs import *

__all__ = ['Dashboard']


class Dashboard(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 can_modifies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 can_views: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_query_parameters: Optional[pulumi.Input[bool]] = None,
                 display_section_table_of_contents: Optional[pulumi.Input[bool]] = None,
                 event_filter_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 parameter_details: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DashboardParameterDetailArgs']]]]] = None,
                 sections: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DashboardSectionArgs']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Provides a Wavefront Dashboard resource.  This allows dashboards to be created, updated, and deleted.

        ## Import

        Dashboards can be imported using the `id`, e.g.

        ```sh
         $ pulumi import wavefront:index/dashboard:Dashboard dashboard tftestimport
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] can_modifies: A list of users that have modify ACL access to the dashboard
        :param pulumi.Input[Sequence[pulumi.Input[str]]] can_views: A list of users that have view ACL access to the dashboard
        :param pulumi.Input[str] description: Human-readable description of the dashboard
        :param pulumi.Input[bool] display_query_parameters: Whether the dashboard parameters section is opened by default when the dashboard
               is shown
        :param pulumi.Input[bool] display_section_table_of_contents: Whether the "pills" quick-linked the sections of the dashboard are 
               displayed by default when the dashboard is shown
        :param pulumi.Input[str] event_filter_type: How charts belonging to this dashboard should display events. BYCHART is default if 
               unspecified; Valid options are: `BYCHART`, `AUTOMATIC`, `ALL`, `NONE`, `BYDASHBOARD`, and `BYCHARTANDDASHBOARD`
        :param pulumi.Input[str] name: Name of the dashboard
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DashboardParameterDetailArgs']]]] parameter_details: The current JSON representation of dashboard parameters. See parameter details
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DashboardSectionArgs']]]] sections: Dashboard chart sections. See dashboard sections
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: A set of tags to assign to this resource.
        :param pulumi.Input[str] url: Unique identifier, also URL slug, of the dashboard
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['can_modifies'] = can_modifies
            __props__['can_views'] = can_views
            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__['description'] = description
            __props__['display_query_parameters'] = display_query_parameters
            __props__['display_section_table_of_contents'] = display_section_table_of_contents
            __props__['event_filter_type'] = event_filter_type
            __props__['name'] = name
            __props__['parameter_details'] = parameter_details
            if sections is None and not opts.urn:
                raise TypeError("Missing required property 'sections'")
            __props__['sections'] = sections
            if tags is None and not opts.urn:
                raise TypeError("Missing required property 'tags'")
            __props__['tags'] = tags
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__['url'] = url
        super(Dashboard, __self__).__init__(
            'wavefront:index/dashboard:Dashboard',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            can_modifies: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            can_views: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            description: Optional[pulumi.Input[str]] = None,
            display_query_parameters: Optional[pulumi.Input[bool]] = None,
            display_section_table_of_contents: Optional[pulumi.Input[bool]] = None,
            event_filter_type: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            parameter_details: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DashboardParameterDetailArgs']]]]] = None,
            sections: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DashboardSectionArgs']]]]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            url: Optional[pulumi.Input[str]] = None) -> 'Dashboard':
        """
        Get an existing Dashboard resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] can_modifies: A list of users that have modify ACL access to the dashboard
        :param pulumi.Input[Sequence[pulumi.Input[str]]] can_views: A list of users that have view ACL access to the dashboard
        :param pulumi.Input[str] description: Human-readable description of the dashboard
        :param pulumi.Input[bool] display_query_parameters: Whether the dashboard parameters section is opened by default when the dashboard
               is shown
        :param pulumi.Input[bool] display_section_table_of_contents: Whether the "pills" quick-linked the sections of the dashboard are 
               displayed by default when the dashboard is shown
        :param pulumi.Input[str] event_filter_type: How charts belonging to this dashboard should display events. BYCHART is default if 
               unspecified; Valid options are: `BYCHART`, `AUTOMATIC`, `ALL`, `NONE`, `BYDASHBOARD`, and `BYCHARTANDDASHBOARD`
        :param pulumi.Input[str] name: Name of the dashboard
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DashboardParameterDetailArgs']]]] parameter_details: The current JSON representation of dashboard parameters. See parameter details
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DashboardSectionArgs']]]] sections: Dashboard chart sections. See dashboard sections
        :param pulumi.Input[Sequence[pulumi.Input[str]]] tags: A set of tags to assign to this resource.
        :param pulumi.Input[str] url: Unique identifier, also URL slug, of the dashboard
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["can_modifies"] = can_modifies
        __props__["can_views"] = can_views
        __props__["description"] = description
        __props__["display_query_parameters"] = display_query_parameters
        __props__["display_section_table_of_contents"] = display_section_table_of_contents
        __props__["event_filter_type"] = event_filter_type
        __props__["name"] = name
        __props__["parameter_details"] = parameter_details
        __props__["sections"] = sections
        __props__["tags"] = tags
        __props__["url"] = url
        return Dashboard(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="canModifies")
    def can_modifies(self) -> pulumi.Output[Sequence[str]]:
        """
        A list of users that have modify ACL access to the dashboard
        """
        return pulumi.get(self, "can_modifies")

    @property
    @pulumi.getter(name="canViews")
    def can_views(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of users that have view ACL access to the dashboard
        """
        return pulumi.get(self, "can_views")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Human-readable description of the dashboard
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayQueryParameters")
    def display_query_parameters(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the dashboard parameters section is opened by default when the dashboard
        is shown
        """
        return pulumi.get(self, "display_query_parameters")

    @property
    @pulumi.getter(name="displaySectionTableOfContents")
    def display_section_table_of_contents(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the "pills" quick-linked the sections of the dashboard are 
        displayed by default when the dashboard is shown
        """
        return pulumi.get(self, "display_section_table_of_contents")

    @property
    @pulumi.getter(name="eventFilterType")
    def event_filter_type(self) -> pulumi.Output[Optional[str]]:
        """
        How charts belonging to this dashboard should display events. BYCHART is default if 
        unspecified; Valid options are: `BYCHART`, `AUTOMATIC`, `ALL`, `NONE`, `BYDASHBOARD`, and `BYCHARTANDDASHBOARD`
        """
        return pulumi.get(self, "event_filter_type")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the dashboard
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="parameterDetails")
    def parameter_details(self) -> pulumi.Output[Optional[Sequence['outputs.DashboardParameterDetail']]]:
        """
        The current JSON representation of dashboard parameters. See parameter details
        """
        return pulumi.get(self, "parameter_details")

    @property
    @pulumi.getter
    def sections(self) -> pulumi.Output[Sequence['outputs.DashboardSection']]:
        """
        Dashboard chart sections. See dashboard sections
        """
        return pulumi.get(self, "sections")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence[str]]:
        """
        A set of tags to assign to this resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[str]:
        """
        Unique identifier, also URL slug, of the dashboard
        """
        return pulumi.get(self, "url")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables

__all__ = [
    'GetDefaultUserGroupResult',
    'AwaitableGetDefaultUserGroupResult',
    'get_default_user_group',
]

@pulumi.output_type
class GetDefaultUserGroupResult:
    """
    A collection of values returned by getDefaultUserGroup.
    """
    def __init__(__self__, group_id=None, id=None):
        if group_id and not isinstance(group_id, str):
            raise TypeError("Expected argument 'group_id' to be a str")
        pulumi.set(__self__, "group_id", group_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> str:
        """
        Set to the Group ID of the `Everyone` group, suitable for referencing
        in other resources that support group memberships. s
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetDefaultUserGroupResult(GetDefaultUserGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDefaultUserGroupResult(
            group_id=self.group_id,
            id=self.id)


def get_default_user_group(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDefaultUserGroupResult:
    """
    Use this data source to get the Group ID of the `Everyone` group in Wavefront.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    everyone_group = wavefront.get_default_user_group()
    ```
    """
    __args__ = dict()
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('wavefront:index/getDefaultUserGroup:getDefaultUserGroup', __args__, opts=opts, typ=GetDefaultUserGroupResult).value

    return AwaitableGetDefaultUserGroupResult(
        group_id=__ret__.group_id,
        id=__ret__.id)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .alert import *
from .alert_target import *
from .cloud_integration_app_dynamics import *
from .cloud_integration_aws_external_id import *
from .cloud_integration_azure import *
from .cloud_integration_azure_activity_log import *
from .cloud_integration_cloud_trail import *
from .cloud_integration_cloud_watch import *
from .cloud_integration_ec2 import *
from .cloud_integration_gcp import *
from .cloud_integration_gcp_billing import *
from .cloud_integration_new_relic import *
from .cloud_integration_tesla import *
from .dashboard import *
from .dashboard_json import *
from .derived_metric import *
from .external_link import *
from .get_default_user_group import *
from .ingestion_policy import *
from .maintenance_window import *
from .provider import *
from .role import *
from .service_account import *
from .user import *
from .user_group import *
from ._inputs import *
from . import outputs

# Make subpackages available:
from . import (
    config,
)

def _register_module():
    import pulumi
    from . import _utilities


    class Module(pulumi.runtime.ResourceModule):
        _version = _utilities.get_semver_version()

        def version(self):
            return Module._version

        def construct(self, name: str, typ: str, urn: str) -> pulumi.Resource:
            if typ == "wavefront:index/alert:Alert":
                return Alert(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/alertTarget:AlertTarget":
                return AlertTarget(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/cloudIntegrationAppDynamics:CloudIntegrationAppDynamics":
                return CloudIntegrationAppDynamics(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/cloudIntegrationAwsExternalId:CloudIntegrationAwsExternalId":
                return CloudIntegrationAwsExternalId(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/cloudIntegrationAzure:CloudIntegrationAzure":
                return CloudIntegrationAzure(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/cloudIntegrationAzureActivityLog:CloudIntegrationAzureActivityLog":
                return CloudIntegrationAzureActivityLog(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/cloudIntegrationCloudTrail:CloudIntegrationCloudTrail":
                return CloudIntegrationCloudTrail(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/cloudIntegrationCloudWatch:CloudIntegrationCloudWatch":
                return CloudIntegrationCloudWatch(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/cloudIntegrationEc2:CloudIntegrationEc2":
                return CloudIntegrationEc2(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/cloudIntegrationGcp:CloudIntegrationGcp":
                return CloudIntegrationGcp(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/cloudIntegrationGcpBilling:CloudIntegrationGcpBilling":
                return CloudIntegrationGcpBilling(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/cloudIntegrationNewRelic:CloudIntegrationNewRelic":
                return CloudIntegrationNewRelic(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/cloudIntegrationTesla:CloudIntegrationTesla":
                return CloudIntegrationTesla(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/dashboard:Dashboard":
                return Dashboard(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/dashboardJson:DashboardJson":
                return DashboardJson(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/derivedMetric:DerivedMetric":
                return DerivedMetric(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/externalLink:ExternalLink":
                return ExternalLink(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/ingestionPolicy:IngestionPolicy":
                return IngestionPolicy(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/maintenanceWindow:MaintenanceWindow":
                return MaintenanceWindow(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/role:Role":
                return Role(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/serviceAccount:ServiceAccount":
                return ServiceAccount(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/user:User":
                return User(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "wavefront:index/userGroup:UserGroup":
                return UserGroup(name, pulumi.ResourceOptions(urn=urn))
            else:
                raise Exception(f"unknown resource type {typ}")


    _module_instance = Module()
    pulumi.runtime.register_resource_module("wavefront", "index/alert", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/alertTarget", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/cloudIntegrationAppDynamics", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/cloudIntegrationAwsExternalId", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/cloudIntegrationAzure", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/cloudIntegrationAzureActivityLog", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/cloudIntegrationCloudTrail", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/cloudIntegrationCloudWatch", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/cloudIntegrationEc2", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/cloudIntegrationGcp", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/cloudIntegrationGcpBilling", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/cloudIntegrationNewRelic", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/cloudIntegrationTesla", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/dashboard", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/dashboardJson", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/derivedMetric", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/externalLink", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/ingestionPolicy", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/maintenanceWindow", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/role", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/serviceAccount", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/user", _module_instance)
    pulumi.runtime.register_resource_module("wavefront", "index/userGroup", _module_instance)


    class Package(pulumi.runtime.ResourcePackage):
        _version = _utilities.get_semver_version()

        def version(self):
            return Package._version

        def construct_provider(self, name: str, typ: str, urn: str) -> pulumi.ProviderResource:
            if typ != "pulumi:providers:wavefront":
                raise Exception(f"unknown provider type {typ}")
            return Provider(name, pulumi.ResourceOptions(urn=urn))


    pulumi.runtime.register_resource_package("wavefront", Package())

_register_module()



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables

__all__ = ['User']


class User(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 customer: Optional[pulumi.Input[str]] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 user_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Provides a Wavefront User Resource. This allows users to be created, updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        basic = wavefront.User("basic", email="test+tftesting@example.com")
        ```

        ## Import

        Users can be imported using the `id`, e.g.

        ```sh
         $ pulumi import wavefront:index/user:User some_user test@example.com
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] email: The (unique) identifier of the user to create. Must be a valid email address
        :param pulumi.Input[Sequence[pulumi.Input[str]]] permissions: List of permission to grant to this user.  Valid options are
               `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
               `host_tag_management`, `metrics_management`, `user_management`
        :param pulumi.Input[Sequence[pulumi.Input[str]]] user_groups: List of user groups to this user
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['customer'] = customer
            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__['email'] = email
            __props__['permissions'] = permissions
            __props__['user_groups'] = user_groups
        super(User, __self__).__init__(
            'wavefront:index/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            customer: Optional[pulumi.Input[str]] = None,
            email: Optional[pulumi.Input[str]] = None,
            permissions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            user_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] email: The (unique) identifier of the user to create. Must be a valid email address
        :param pulumi.Input[Sequence[pulumi.Input[str]]] permissions: List of permission to grant to this user.  Valid options are
               `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
               `host_tag_management`, `metrics_management`, `user_management`
        :param pulumi.Input[Sequence[pulumi.Input[str]]] user_groups: List of user groups to this user
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["customer"] = customer
        __props__["email"] = email
        __props__["permissions"] = permissions
        __props__["user_groups"] = user_groups
        return User(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def customer(self) -> pulumi.Output[str]:
        return pulumi.get(self, "customer")

    @property
    @pulumi.getter
    def email(self) -> pulumi.Output[str]:
        """
        The (unique) identifier of the user to create. Must be a valid email address
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def permissions(self) -> pulumi.Output[Sequence[str]]:
        """
        List of permission to grant to this user.  Valid options are
        `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
        `host_tag_management`, `metrics_management`, `user_management`
        """
        return pulumi.get(self, "permissions")

    @property
    @pulumi.getter(name="userGroups")
    def user_groups(self) -> pulumi.Output[Sequence[str]]:
        """
        List of user groups to this user
        """
        return pulumi.get(self, "user_groups")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables
from . import outputs

__all__ = [
    'AlertTargetRoute',
    'CloudIntegrationNewRelicMetricFilter',
    'DashboardParameterDetail',
    'DashboardSection',
    'DashboardSectionRow',
    'DashboardSectionRowChart',
    'DashboardSectionRowChartChartSetting',
    'DashboardSectionRowChartSource',
]

@pulumi.output_type
class AlertTargetRoute(dict):
    def __init__(__self__, *,
                 method: str,
                 target: str,
                 filter: Optional[Mapping[str, str]] = None):
        """
        :param str method: The notification method used for notification target. One of `WEBHOOK`, `EMAIL`, `PAGERDUTY`.
        """
        pulumi.set(__self__, "method", method)
        pulumi.set(__self__, "target", target)
        if filter is not None:
            pulumi.set(__self__, "filter", filter)

    @property
    @pulumi.getter
    def method(self) -> str:
        """
        The notification method used for notification target. One of `WEBHOOK`, `EMAIL`, `PAGERDUTY`.
        """
        return pulumi.get(self, "method")

    @property
    @pulumi.getter
    def target(self) -> str:
        return pulumi.get(self, "target")

    @property
    @pulumi.getter
    def filter(self) -> Optional[Mapping[str, str]]:
        return pulumi.get(self, "filter")

    def _translate_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop


@pulumi.output_type
class CloudIntegrationNewRelicMetricFilter(dict):
    def __init__(__self__, *,
                 app_name: str,
                 metric_filter_regex: str):
        """
        :param str app_name: The name of a NewRelic App
        :param str metric_filter_regex: A regular expression that a metric name must match (case-insensitively) in order to be ingested
        """
        pulumi.set(__self__, "app_name", app_name)
        pulumi.set(__self__, "metric_filter_regex", metric_filter_regex)

    @property
    @pulumi.getter(name="appName")
    def app_name(self) -> str:
        """
        The name of a NewRelic App
        """
        return pulumi.get(self, "app_name")

    @property
    @pulumi.getter(name="metricFilterRegex")
    def metric_filter_regex(self) -> str:
        """
        A regular expression that a metric name must match (case-insensitively) in order to be ingested
        """
        return pulumi.get(self, "metric_filter_regex")

    def _translate_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop


@pulumi.output_type
class DashboardParameterDetail(dict):
    def __init__(__self__, *,
                 default_value: str,
                 hide_from_view: bool,
                 label: str,
                 name: str,
                 parameter_type: str,
                 values_to_readable_strings: Mapping[str, str],
                 dynamic_field_type: Optional[str] = None,
                 query_value: Optional[str] = None,
                 tag_key: Optional[str] = None):
        """
        :param str default_value: The default value of the parameter
        :param bool hide_from_view: If `true` the parameter will only be shown on the edit view of the dashboard
        :param str label: The label for the parameter
        :param str name: The name of the parameters
        :param str parameter_type: The type of the parameter. `SIMPLE`, `LIST`, or `DYNAMIC`
        :param Mapping[str, str] values_to_readable_strings: A string->string map.  At least one of the keys must match the value of
               `default_value`
        :param str dynamic_field_type: For `DYNAMIC` parameter types, the type of the field. Valid options are `SOURCE`,
               `SOURCE_TAG`, `METRIC_NAME`, `TAG_KEY`, `MATCHING_SOURCE_TAG`
        :param str query_value: For `DYNAMIC` parameter types, the query to execute to return values
        :param str tag_key: for `TAG_KEY` dynamic field types, the tag key to return
        """
        pulumi.set(__self__, "default_value", default_value)
        pulumi.set(__self__, "hide_from_view", hide_from_view)
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "parameter_type", parameter_type)
        pulumi.set(__self__, "values_to_readable_strings", values_to_readable_strings)
        if dynamic_field_type is not None:
            pulumi.set(__self__, "dynamic_field_type", dynamic_field_type)
        if query_value is not None:
            pulumi.set(__self__, "query_value", query_value)
        if tag_key is not None:
            pulumi.set(__self__, "tag_key", tag_key)

    @property
    @pulumi.getter(name="defaultValue")
    def default_value(self) -> str:
        """
        The default value of the parameter
        """
        return pulumi.get(self, "default_value")

    @property
    @pulumi.getter(name="hideFromView")
    def hide_from_view(self) -> bool:
        """
        If `true` the parameter will only be shown on the edit view of the dashboard
        """
        return pulumi.get(self, "hide_from_view")

    @property
    @pulumi.getter
    def label(self) -> str:
        """
        The label for the parameter
        """
        return pulumi.get(self, "label")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the parameters
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="parameterType")
    def parameter_type(self) -> str:
        """
        The type of the parameter. `SIMPLE`, `LIST`, or `DYNAMIC`
        """
        return pulumi.get(self, "parameter_type")

    @property
    @pulumi.getter(name="valuesToReadableStrings")
    def values_to_readable_strings(self) -> Mapping[str, str]:
        """
        A string->string map.  At least one of the keys must match the value of
        `default_value`
        """
        return pulumi.get(self, "values_to_readable_strings")

    @property
    @pulumi.getter(name="dynamicFieldType")
    def dynamic_field_type(self) -> Optional[str]:
        """
        For `DYNAMIC` parameter types, the type of the field. Valid options are `SOURCE`,
        `SOURCE_TAG`, `METRIC_NAME`, `TAG_KEY`, `MATCHING_SOURCE_TAG`
        """
        return pulumi.get(self, "dynamic_field_type")

    @property
    @pulumi.getter(name="queryValue")
    def query_value(self) -> Optional[str]:
        """
        For `DYNAMIC` parameter types, the query to execute to return values
        """
        return pulumi.get(self, "query_value")

    @property
    @pulumi.getter(name="tagKey")
    def tag_key(self) -> Optional[str]:
        """
        for `TAG_KEY` dynamic field types, the tag key to return
        """
        return pulumi.get(self, "tag_key")

    def _translate_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop


@pulumi.output_type
class DashboardSection(dict):
    def __init__(__self__, *,
                 name: str,
                 rows: Sequence['outputs.DashboardSectionRow']):
        """
        :param str name: Name of this section
        :param Sequence['DashboardSectionRowArgs'] rows: See dashboard section rows
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "rows", rows)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of this section
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def rows(self) -> Sequence['outputs.DashboardSectionRow']:
        """
        See dashboard section rows
        """
        return pulumi.get(self, "rows")

    def _translate_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop


@pulumi.output_type
class DashboardSectionRow(dict):
    def __init__(__self__, *,
                 charts: Sequence['outputs.DashboardSectionRowChart']):
        """
        :param Sequence['DashboardSectionRowChartArgs'] charts: Charts in this section. See dashboard chart
        """
        pulumi.set(__self__, "charts", charts)

    @property
    @pulumi.getter
    def charts(self) -> Sequence['outputs.DashboardSectionRowChart']:
        """
        Charts in this section. See dashboard chart
        """
        return pulumi.get(self, "charts")

    def _translate_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop


@pulumi.output_type
class DashboardSectionRowChart(dict):
    def __init__(__self__, *,
                 chart_setting: 'outputs.DashboardSectionRowChartChartSetting',
                 name: str,
                 sources: Sequence['outputs.DashboardSectionRowChartSource'],
                 summarization: str,
                 units: str,
                 base: Optional[int] = None,
                 chart_attribute: Optional[str] = None,
                 description: Optional[str] = None):
        """
        :param 'DashboardSectionRowChartChartSettingArgs' chart_setting: Chart settings. See chart settings
        :param str name: Name of the source
        :param Sequence['DashboardSectionRowChartSourceArgs'] sources: Query expression to plot on the chart. See chart source queries
        :param str summarization: Summarization strategy for the chart. MEAN is default. Valid options are, `MEAN`, 
               `MEDIAN`, `MIN`, `MAX`, `SUM`, `COUNT`, `LAST`, `FIRST`
        :param str units: String to label the units of the chart on the Y-Axis
        :param int base: The base of logarithmic scale charts. Omit or set to 0 for the default linear scale. Usually set to 10 for the traditional logarithmic scale.
        :param str description: Description of the chart
        """
        pulumi.set(__self__, "chart_setting", chart_setting)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "sources", sources)
        pulumi.set(__self__, "summarization", summarization)
        pulumi.set(__self__, "units", units)
        if base is not None:
            pulumi.set(__self__, "base", base)
        if chart_attribute is not None:
            pulumi.set(__self__, "chart_attribute", chart_attribute)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="chartSetting")
    def chart_setting(self) -> 'outputs.DashboardSectionRowChartChartSetting':
        """
        Chart settings. See chart settings
        """
        return pulumi.get(self, "chart_setting")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the source
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def sources(self) -> Sequence['outputs.DashboardSectionRowChartSource']:
        """
        Query expression to plot on the chart. See chart source queries
        """
        return pulumi.get(self, "sources")

    @property
    @pulumi.getter
    def summarization(self) -> str:
        """
        Summarization strategy for the chart. MEAN is default. Valid options are, `MEAN`, 
        `MEDIAN`, `MIN`, `MAX`, `SUM`, `COUNT`, `LAST`, `FIRST`
        """
        return pulumi.get(self, "summarization")

    @property
    @pulumi.getter
    def units(self) -> str:
        """
        String to label the units of the chart on the Y-Axis
        """
        return pulumi.get(self, "units")

    @property
    @pulumi.getter
    def base(self) -> Optional[int]:
        """
        The base of logarithmic scale charts. Omit or set to 0 for the default linear scale. Usually set to 10 for the traditional logarithmic scale.
        """
        return pulumi.get(self, "base")

    @property
    @pulumi.getter(name="chartAttribute")
    def chart_attribute(self) -> Optional[str]:
        return pulumi.get(self, "chart_attribute")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        Description of the chart
        """
        return pulumi.get(self, "description")

    def _translate_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop


@pulumi.output_type
class DashboardSectionRowChartChartSetting(dict):
    def __init__(__self__, *,
                 type: str,
                 auto_column_tags: Optional[bool] = None,
                 column_tags: Optional[str] = None,
                 custom_tags: Optional[Sequence[str]] = None,
                 expected_data_spacing: Optional[int] = None,
                 fixed_legend_display_stats: Optional[Sequence[str]] = None,
                 fixed_legend_enabled: Optional[bool] = None,
                 fixed_legend_filter_field: Optional[str] = None,
                 fixed_legend_filter_limit: Optional[int] = None,
                 fixed_legend_filter_sort: Optional[str] = None,
                 fixed_legend_hide_label: Optional[bool] = None,
                 fixed_legend_position: Optional[str] = None,
                 fixed_legend_use_raw_stats: Optional[bool] = None,
                 group_by_source: Optional[bool] = None,
                 invert_dynamic_legend_hover_control: Optional[bool] = None,
                 line_type: Optional[str] = None,
                 max: Optional[float] = None,
                 min: Optional[float] = None,
                 num_tags: Optional[int] = None,
                 plain_markdown_content: Optional[str] = None,
                 show_hosts: Optional[bool] = None,
                 show_labels: Optional[bool] = None,
                 show_raw_values: Optional[bool] = None,
                 sort_values_descending: Optional[bool] = None,
                 sparkline_decimal_precision: Optional[int] = None,
                 sparkline_display_color: Optional[str] = None,
                 sparkline_display_font_size: Optional[str] = None,
                 sparkline_display_horizontal_position: Optional[str] = None,
                 sparkline_display_postfix: Optional[str] = None,
                 sparkline_display_prefix: Optional[str] = None,
                 sparkline_display_value_type: Optional[str] = None,
                 sparkline_display_vertical_position: Optional[str] = None,
                 sparkline_fill_color: Optional[str] = None,
                 sparkline_line_color: Optional[str] = None,
                 sparkline_size: Optional[str] = None,
                 sparkline_value_color_map_apply_to: Optional[str] = None,
                 sparkline_value_color_map_colors: Optional[Sequence[str]] = None,
                 sparkline_value_color_map_values: Optional[Sequence[int]] = None,
                 sparkline_value_color_map_values_v2s: Optional[Sequence[float]] = None,
                 sparkline_value_text_map_texts: Optional[Sequence[str]] = None,
                 sparkline_value_text_map_thresholds: Optional[Sequence[float]] = None,
                 stack_type: Optional[str] = None,
                 tag_mode: Optional[str] = None,
                 time_based_coloring: Optional[bool] = None,
                 window_size: Optional[int] = None,
                 windowing: Optional[str] = None,
                 xmax: Optional[float] = None,
                 xmin: Optional[float] = None,
                 y0_scale_si_by1024: Optional[bool] = None,
                 y0_unit_autoscaling: Optional[bool] = None,
                 y1_scale_si_by1024: Optional[bool] = None,
                 y1_unit_autoscaling: Optional[bool] = None,
                 y1_units: Optional[str] = None,
                 y1max: Optional[float] = None,
                 y1min: Optional[float] = None,
                 ymax: Optional[float] = None,
                 ymin: Optional[float] = None):
        """
        :param str type: Chart Type. `line` refers to the Line Plot, `scatter` to the Point Plot, `stacked-area` to 
               the Stacked Area plot, `table` to the Tabular View, `scatterploy-xy` to Scatter Plot, `markdown-widget` to the
               Markdown display, and `sparkline` to the Single Stat view. Valid options are `line`, `scatterplot`,
               `stacked-area`, `stacked-column`, `table`, `scatterplot-xy`, `markdown-widget`, `sparkline`, `globe`, `nodemap`,
               `top-k`, `status-list`, `histogram`
        :param bool auto_column_tags: deprecated
        :param str column_tags: deprecated
        :param Sequence[str] custom_tags: For the tabular view, a list of point tags to display when using the `custom` tag display mode
        :param int expected_data_spacing: Threshold (in seconds) for time delta between consecutive points in a series
               above which a dotted line will replace a solid in in line plots. Default 60
        :param Sequence[str] fixed_legend_display_stats: For a chart with a fixed legend, a list of statistics to display in the legend
        :param bool fixed_legend_enabled: Whether to enable a fixed tabular legend adjacent to the chart
        :param str fixed_legend_filter_field: Statistic to use for determining whether a series is displayed on the fixed legend.
               Valid options are `CURRENT`, `MEAN`, `MEDIAN`, `SUM`, `MIN`, `MAX`, `COUNT`
        :param int fixed_legend_filter_limit: Number of series to include in the fixed legend
        :param str fixed_legend_filter_sort: Whether to display `TOP` or `BOTTOM` ranked series in a fixed legend. Valid options
               are `TOP`, and `BOTTOM`
        :param bool fixed_legend_hide_label: deprecated
        :param str fixed_legend_position: Where the fixed legend should be displayed with respect ot the chart.
               Valid options are `RIGHt`, `TOP`, `LEFT`, `BOTTOM`
        :param bool fixed_legend_use_raw_stats: If `true`, the legend uses non-summarized stats instead of summarized
        :param bool group_by_source: For the tabular view, whether to group multi metrics into a single row by a common source.
               If `false`, each source is displayed in its own row.  if `true`, multiple metrics for the same host will be displayed as different
               columns in the same row
        :param bool invert_dynamic_legend_hover_control: Whether to disable the display of the floating legend (but
               reenable it when the ctrl-key is pressed)
        :param str line_type: Plot interpolation type.  `linear` is default. Valid options are `linear`, `step-before`, 
               `step-after`, `basis`, `cardinal`, `monotone`
        :param float max: Max value of the Y-axis. Set to null or leave blank for auto
        :param float min: Min value of the Y-axis. Set to null or leave blank for auto
        :param int num_tags: For the tabular view, how many point tags to display
        :param str plain_markdown_content: The markdown content for a Markdown display, in plain text.
        :param bool show_hosts: For the tabular view, whether to display sources. Default is `true`
        :param bool show_labels: For the tabular view, whether to display labels. Default is `true`
        :param bool show_raw_values: For the tabular view, whether to display raw values. Default is `false`
        :param bool sort_values_descending: For the tabular view, whether to display display values in descending order. Default is `false`
        :param int sparkline_decimal_precision: For the single stat view, the decimal precision of the displayed number
        :param str sparkline_display_color: For the single stat view, the color of the displayed text (when not dynamically determined). 
               Values should be in `rgba(,,,,)` format
        :param str sparkline_display_font_size: For the single stat view, the font size of the displayed text, in percent
        :param str sparkline_display_horizontal_position: For the single stat view, the horizontal position of the displayed text.
               Valid options are `MIDDLE`, `LEFT`, `RIGHT`
        :param str sparkline_display_postfix: For the single stat view, a string to append to the displayed text
        :param str sparkline_display_prefix: For the single stat view, a string to add before the displayed text
        :param str sparkline_display_value_type: For the single stat view, where to display the name of the query or the value of the query.
               Valid options are `VALUE` or `LABEL`
        :param str sparkline_display_vertical_position: deprecated
        :param str sparkline_fill_color: For the single stat view, the color of the background fill.  Values should be
               in `rgba(,,,,)`
        :param str sparkline_line_color: For the single stat view, the color of the line.  Values should be in `rgba(,,,,)` format
        :param str sparkline_size: For the single stat view, This determines whether the sparkline of the statistic is displayed in the chart `BACKGROUND`, `BOTTOM`, or `NONE`.
               Valid options are `BACKGROUND`, `BOTTOM`, `NONE`
        :param str sparkline_value_color_map_apply_to: For the single stat view, whether to apply dyunamic color settings to 
               the displayed `TEXT` or `BACKGROUND`. Valid options are `TEXT` or `BACKGROUND`
        :param Sequence[str] sparkline_value_color_map_colors: For the single stat view, A list of colors that differing query values map to. 
               Must contain one more element than `sparkline_value_color_map_values_v2`. Values should be in `rgba(,,,,)`
        :param Sequence[int] sparkline_value_color_map_values: deprecated
        :param Sequence[float] sparkline_value_color_map_values_v2s: For the single stat view, a list of boundaries for mapping different
               query values to colors.  Must contain one less element than `sparkline_value_color_map_colors`
        :param Sequence[str] sparkline_value_text_map_texts: For the single stat view, a list of display text values that different query
               values map to.  Must contain one more element than `sparkline_value_text_map_thresholds`
        :param Sequence[float] sparkline_value_text_map_thresholds: For the single stat view, a list of threshold boundaries for 
               mapping different query values to display text.  Must contain one less element than `sparkline_value_text_map_text`
        :param str stack_type: Type of stacked chart (applicable only if chart type is `stacked`). `zero` (default) means
               stacked from y=0. `expand` means normalized from 0 to 1.  `wiggle` means minimize weighted changes. `silhouette` means to
               center the stream. Valid options are `zero`, `expand`, `wiggle`, `silhouette`, `bars`
        :param str tag_mode: For the tabular view, which mode to use to determine which point tags to display.
               Valid options are `all`, `top`, or `custom`
        :param bool time_based_coloring: For x-y scatterplots, whether to color more recent points as darker than older points
        :param int window_size: Width, in minutes, of the time window to use for `last` windowing
        :param str windowing: For the tabular view, whether to use the full time window for the query or the last X minutes.
               Valid options are `full` or `last`
        :param float xmax: For x-y scatterplots, max value for the X-axis. Set to null for auto
        :param float xmin: For x-y scatterplots, min value for the X-axis. Set to null for auto
        :param bool y0_scale_si_by1024: Whether to scale numerical magnitude labels for left Y-axis by 1024 in the IEC/Binary manner (instead of by 1000 like SI)
        :param bool y0_unit_autoscaling: Whether to automatically adjust magnitude labels and units for the left Y-axis to favor smaller magnitudes and larger units
        :param bool y1_scale_si_by1024: Whether to scale numerical magnitude labels for right Y-axis by 1024 in the IEC/Binary manner (instead of by 1000 like SI)
        :param bool y1_unit_autoscaling: Whether to automatically adjust magnitude labels and units for the right Y-axis to favor smaller magnitudes and larger units
        :param str y1_units: For plots with multiple Y-axes, units for right side Y-axis
        :param float y1max: For plots with multiple Y-axes, max value for the right side Y-axis. Set null for auto
        :param float y1min: For plots with multiple Y-axes, min value for the right side Y-axis. Set null for auto
        :param float ymax: For x-y scatterplots, max value for the Y-axis. Set to null for auto
        :param float ymin: For x-y scatterplots, min value for the Y-axis. Set to null for auto
        """
        pulumi.set(__self__, "type", type)
        if auto_column_tags is not None:
            pulumi.set(__self__, "auto_column_tags", auto_column_tags)
        if column_tags is not None:
            pulumi.set(__self__, "column_tags", column_tags)
        if custom_tags is not None:
            pulumi.set(__self__, "custom_tags", custom_tags)
        if expected_data_spacing is not None:
            pulumi.set(__self__, "expected_data_spacing", expected_data_spacing)
        if fixed_legend_display_stats is not None:
            pulumi.set(__self__, "fixed_legend_display_stats", fixed_legend_display_stats)
        if fixed_legend_enabled is not None:
            pulumi.set(__self__, "fixed_legend_enabled", fixed_legend_enabled)
        if fixed_legend_filter_field is not None:
            pulumi.set(__self__, "fixed_legend_filter_field", fixed_legend_filter_field)
        if fixed_legend_filter_limit is not None:
            pulumi.set(__self__, "fixed_legend_filter_limit", fixed_legend_filter_limit)
        if fixed_legend_filter_sort is not None:
            pulumi.set(__self__, "fixed_legend_filter_sort", fixed_legend_filter_sort)
        if fixed_legend_hide_label is not None:
            pulumi.set(__self__, "fixed_legend_hide_label", fixed_legend_hide_label)
        if fixed_legend_position is not None:
            pulumi.set(__self__, "fixed_legend_position", fixed_legend_position)
        if fixed_legend_use_raw_stats is not None:
            pulumi.set(__self__, "fixed_legend_use_raw_stats", fixed_legend_use_raw_stats)
        if group_by_source is not None:
            pulumi.set(__self__, "group_by_source", group_by_source)
        if invert_dynamic_legend_hover_control is not None:
            pulumi.set(__self__, "invert_dynamic_legend_hover_control", invert_dynamic_legend_hover_control)
        if line_type is not None:
            pulumi.set(__self__, "line_type", line_type)
        if max is not None:
            pulumi.set(__self__, "max", max)
        if min is not None:
            pulumi.set(__self__, "min", min)
        if num_tags is not None:
            pulumi.set(__self__, "num_tags", num_tags)
        if plain_markdown_content is not None:
            pulumi.set(__self__, "plain_markdown_content", plain_markdown_content)
        if show_hosts is not None:
            pulumi.set(__self__, "show_hosts", show_hosts)
        if show_labels is not None:
            pulumi.set(__self__, "show_labels", show_labels)
        if show_raw_values is not None:
            pulumi.set(__self__, "show_raw_values", show_raw_values)
        if sort_values_descending is not None:
            pulumi.set(__self__, "sort_values_descending", sort_values_descending)
        if sparkline_decimal_precision is not None:
            pulumi.set(__self__, "sparkline_decimal_precision", sparkline_decimal_precision)
        if sparkline_display_color is not None:
            pulumi.set(__self__, "sparkline_display_color", sparkline_display_color)
        if sparkline_display_font_size is not None:
            pulumi.set(__self__, "sparkline_display_font_size", sparkline_display_font_size)
        if sparkline_display_horizontal_position is not None:
            pulumi.set(__self__, "sparkline_display_horizontal_position", sparkline_display_horizontal_position)
        if sparkline_display_postfix is not None:
            pulumi.set(__self__, "sparkline_display_postfix", sparkline_display_postfix)
        if sparkline_display_prefix is not None:
            pulumi.set(__self__, "sparkline_display_prefix", sparkline_display_prefix)
        if sparkline_display_value_type is not None:
            pulumi.set(__self__, "sparkline_display_value_type", sparkline_display_value_type)
        if sparkline_display_vertical_position is not None:
            pulumi.set(__self__, "sparkline_display_vertical_position", sparkline_display_vertical_position)
        if sparkline_fill_color is not None:
            pulumi.set(__self__, "sparkline_fill_color", sparkline_fill_color)
        if sparkline_line_color is not None:
            pulumi.set(__self__, "sparkline_line_color", sparkline_line_color)
        if sparkline_size is not None:
            pulumi.set(__self__, "sparkline_size", sparkline_size)
        if sparkline_value_color_map_apply_to is not None:
            pulumi.set(__self__, "sparkline_value_color_map_apply_to", sparkline_value_color_map_apply_to)
        if sparkline_value_color_map_colors is not None:
            pulumi.set(__self__, "sparkline_value_color_map_colors", sparkline_value_color_map_colors)
        if sparkline_value_color_map_values is not None:
            pulumi.set(__self__, "sparkline_value_color_map_values", sparkline_value_color_map_values)
        if sparkline_value_color_map_values_v2s is not None:
            pulumi.set(__self__, "sparkline_value_color_map_values_v2s", sparkline_value_color_map_values_v2s)
        if sparkline_value_text_map_texts is not None:
            pulumi.set(__self__, "sparkline_value_text_map_texts", sparkline_value_text_map_texts)
        if sparkline_value_text_map_thresholds is not None:
            pulumi.set(__self__, "sparkline_value_text_map_thresholds", sparkline_value_text_map_thresholds)
        if stack_type is not None:
            pulumi.set(__self__, "stack_type", stack_type)
        if tag_mode is not None:
            pulumi.set(__self__, "tag_mode", tag_mode)
        if time_based_coloring is not None:
            pulumi.set(__self__, "time_based_coloring", time_based_coloring)
        if window_size is not None:
            pulumi.set(__self__, "window_size", window_size)
        if windowing is not None:
            pulumi.set(__self__, "windowing", windowing)
        if xmax is not None:
            pulumi.set(__self__, "xmax", xmax)
        if xmin is not None:
            pulumi.set(__self__, "xmin", xmin)
        if y0_scale_si_by1024 is not None:
            pulumi.set(__self__, "y0_scale_si_by1024", y0_scale_si_by1024)
        if y0_unit_autoscaling is not None:
            pulumi.set(__self__, "y0_unit_autoscaling", y0_unit_autoscaling)
        if y1_scale_si_by1024 is not None:
            pulumi.set(__self__, "y1_scale_si_by1024", y1_scale_si_by1024)
        if y1_unit_autoscaling is not None:
            pulumi.set(__self__, "y1_unit_autoscaling", y1_unit_autoscaling)
        if y1_units is not None:
            pulumi.set(__self__, "y1_units", y1_units)
        if y1max is not None:
            pulumi.set(__self__, "y1max", y1max)
        if y1min is not None:
            pulumi.set(__self__, "y1min", y1min)
        if ymax is not None:
            pulumi.set(__self__, "ymax", ymax)
        if ymin is not None:
            pulumi.set(__self__, "ymin", ymin)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Chart Type. `line` refers to the Line Plot, `scatter` to the Point Plot, `stacked-area` to 
        the Stacked Area plot, `table` to the Tabular View, `scatterploy-xy` to Scatter Plot, `markdown-widget` to the
        Markdown display, and `sparkline` to the Single Stat view. Valid options are `line`, `scatterplot`,
        `stacked-area`, `stacked-column`, `table`, `scatterplot-xy`, `markdown-widget`, `sparkline`, `globe`, `nodemap`,
        `top-k`, `status-list`, `histogram`
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="autoColumnTags")
    def auto_column_tags(self) -> Optional[bool]:
        """
        deprecated
        """
        return pulumi.get(self, "auto_column_tags")

    @property
    @pulumi.getter(name="columnTags")
    def column_tags(self) -> Optional[str]:
        """
        deprecated
        """
        return pulumi.get(self, "column_tags")

    @property
    @pulumi.getter(name="customTags")
    def custom_tags(self) -> Optional[Sequence[str]]:
        """
        For the tabular view, a list of point tags to display when using the `custom` tag display mode
        """
        return pulumi.get(self, "custom_tags")

    @property
    @pulumi.getter(name="expectedDataSpacing")
    def expected_data_spacing(self) -> Optional[int]:
        """
        Threshold (in seconds) for time delta between consecutive points in a series
        above which a dotted line will replace a solid in in line plots. Default 60
        """
        return pulumi.get(self, "expected_data_spacing")

    @property
    @pulumi.getter(name="fixedLegendDisplayStats")
    def fixed_legend_display_stats(self) -> Optional[Sequence[str]]:
        """
        For a chart with a fixed legend, a list of statistics to display in the legend
        """
        return pulumi.get(self, "fixed_legend_display_stats")

    @property
    @pulumi.getter(name="fixedLegendEnabled")
    def fixed_legend_enabled(self) -> Optional[bool]:
        """
        Whether to enable a fixed tabular legend adjacent to the chart
        """
        return pulumi.get(self, "fixed_legend_enabled")

    @property
    @pulumi.getter(name="fixedLegendFilterField")
    def fixed_legend_filter_field(self) -> Optional[str]:
        """
        Statistic to use for determining whether a series is displayed on the fixed legend.
        Valid options are `CURRENT`, `MEAN`, `MEDIAN`, `SUM`, `MIN`, `MAX`, `COUNT`
        """
        return pulumi.get(self, "fixed_legend_filter_field")

    @property
    @pulumi.getter(name="fixedLegendFilterLimit")
    def fixed_legend_filter_limit(self) -> Optional[int]:
        """
        Number of series to include in the fixed legend
        """
        return pulumi.get(self, "fixed_legend_filter_limit")

    @property
    @pulumi.getter(name="fixedLegendFilterSort")
    def fixed_legend_filter_sort(self) -> Optional[str]:
        """
        Whether to display `TOP` or `BOTTOM` ranked series in a fixed legend. Valid options
        are `TOP`, and `BOTTOM`
        """
        return pulumi.get(self, "fixed_legend_filter_sort")

    @property
    @pulumi.getter(name="fixedLegendHideLabel")
    def fixed_legend_hide_label(self) -> Optional[bool]:
        """
        deprecated
        """
        return pulumi.get(self, "fixed_legend_hide_label")

    @property
    @pulumi.getter(name="fixedLegendPosition")
    def fixed_legend_position(self) -> Optional[str]:
        """
        Where the fixed legend should be displayed with respect ot the chart.
        Valid options are `RIGHt`, `TOP`, `LEFT`, `BOTTOM`
        """
        return pulumi.get(self, "fixed_legend_position")

    @property
    @pulumi.getter(name="fixedLegendUseRawStats")
    def fixed_legend_use_raw_stats(self) -> Optional[bool]:
        """
        If `true`, the legend uses non-summarized stats instead of summarized
        """
        return pulumi.get(self, "fixed_legend_use_raw_stats")

    @property
    @pulumi.getter(name="groupBySource")
    def group_by_source(self) -> Optional[bool]:
        """
        For the tabular view, whether to group multi metrics into a single row by a common source.
        If `false`, each source is displayed in its own row.  if `true`, multiple metrics for the same host will be displayed as different
        columns in the same row
        """
        return pulumi.get(self, "group_by_source")

    @property
    @pulumi.getter(name="invertDynamicLegendHoverControl")
    def invert_dynamic_legend_hover_control(self) -> Optional[bool]:
        """
        Whether to disable the display of the floating legend (but
        reenable it when the ctrl-key is pressed)
        """
        return pulumi.get(self, "invert_dynamic_legend_hover_control")

    @property
    @pulumi.getter(name="lineType")
    def line_type(self) -> Optional[str]:
        """
        Plot interpolation type.  `linear` is default. Valid options are `linear`, `step-before`, 
        `step-after`, `basis`, `cardinal`, `monotone`
        """
        return pulumi.get(self, "line_type")

    @property
    @pulumi.getter
    def max(self) -> Optional[float]:
        """
        Max value of the Y-axis. Set to null or leave blank for auto
        """
        return pulumi.get(self, "max")

    @property
    @pulumi.getter
    def min(self) -> Optional[float]:
        """
        Min value of the Y-axis. Set to null or leave blank for auto
        """
        return pulumi.get(self, "min")

    @property
    @pulumi.getter(name="numTags")
    def num_tags(self) -> Optional[int]:
        """
        For the tabular view, how many point tags to display
        """
        return pulumi.get(self, "num_tags")

    @property
    @pulumi.getter(name="plainMarkdownContent")
    def plain_markdown_content(self) -> Optional[str]:
        """
        The markdown content for a Markdown display, in plain text.
        """
        return pulumi.get(self, "plain_markdown_content")

    @property
    @pulumi.getter(name="showHosts")
    def show_hosts(self) -> Optional[bool]:
        """
        For the tabular view, whether to display sources. Default is `true`
        """
        return pulumi.get(self, "show_hosts")

    @property
    @pulumi.getter(name="showLabels")
    def show_labels(self) -> Optional[bool]:
        """
        For the tabular view, whether to display labels. Default is `true`
        """
        return pulumi.get(self, "show_labels")

    @property
    @pulumi.getter(name="showRawValues")
    def show_raw_values(self) -> Optional[bool]:
        """
        For the tabular view, whether to display raw values. Default is `false`
        """
        return pulumi.get(self, "show_raw_values")

    @property
    @pulumi.getter(name="sortValuesDescending")
    def sort_values_descending(self) -> Optional[bool]:
        """
        For the tabular view, whether to display display values in descending order. Default is `false`
        """
        return pulumi.get(self, "sort_values_descending")

    @property
    @pulumi.getter(name="sparklineDecimalPrecision")
    def sparkline_decimal_precision(self) -> Optional[int]:
        """
        For the single stat view, the decimal precision of the displayed number
        """
        return pulumi.get(self, "sparkline_decimal_precision")

    @property
    @pulumi.getter(name="sparklineDisplayColor")
    def sparkline_display_color(self) -> Optional[str]:
        """
        For the single stat view, the color of the displayed text (when not dynamically determined). 
        Values should be in `rgba(,,,,)` format
        """
        return pulumi.get(self, "sparkline_display_color")

    @property
    @pulumi.getter(name="sparklineDisplayFontSize")
    def sparkline_display_font_size(self) -> Optional[str]:
        """
        For the single stat view, the font size of the displayed text, in percent
        """
        return pulumi.get(self, "sparkline_display_font_size")

    @property
    @pulumi.getter(name="sparklineDisplayHorizontalPosition")
    def sparkline_display_horizontal_position(self) -> Optional[str]:
        """
        For the single stat view, the horizontal position of the displayed text.
        Valid options are `MIDDLE`, `LEFT`, `RIGHT`
        """
        return pulumi.get(self, "sparkline_display_horizontal_position")

    @property
    @pulumi.getter(name="sparklineDisplayPostfix")
    def sparkline_display_postfix(self) -> Optional[str]:
        """
        For the single stat view, a string to append to the displayed text
        """
        return pulumi.get(self, "sparkline_display_postfix")

    @property
    @pulumi.getter(name="sparklineDisplayPrefix")
    def sparkline_display_prefix(self) -> Optional[str]:
        """
        For the single stat view, a string to add before the displayed text
        """
        return pulumi.get(self, "sparkline_display_prefix")

    @property
    @pulumi.getter(name="sparklineDisplayValueType")
    def sparkline_display_value_type(self) -> Optional[str]:
        """
        For the single stat view, where to display the name of the query or the value of the query.
        Valid options are `VALUE` or `LABEL`
        """
        return pulumi.get(self, "sparkline_display_value_type")

    @property
    @pulumi.getter(name="sparklineDisplayVerticalPosition")
    def sparkline_display_vertical_position(self) -> Optional[str]:
        """
        deprecated
        """
        return pulumi.get(self, "sparkline_display_vertical_position")

    @property
    @pulumi.getter(name="sparklineFillColor")
    def sparkline_fill_color(self) -> Optional[str]:
        """
        For the single stat view, the color of the background fill.  Values should be
        in `rgba(,,,,)`
        """
        return pulumi.get(self, "sparkline_fill_color")

    @property
    @pulumi.getter(name="sparklineLineColor")
    def sparkline_line_color(self) -> Optional[str]:
        """
        For the single stat view, the color of the line.  Values should be in `rgba(,,,,)` format
        """
        return pulumi.get(self, "sparkline_line_color")

    @property
    @pulumi.getter(name="sparklineSize")
    def sparkline_size(self) -> Optional[str]:
        """
        For the single stat view, This determines whether the sparkline of the statistic is displayed in the chart `BACKGROUND`, `BOTTOM`, or `NONE`.
        Valid options are `BACKGROUND`, `BOTTOM`, `NONE`
        """
        return pulumi.get(self, "sparkline_size")

    @property
    @pulumi.getter(name="sparklineValueColorMapApplyTo")
    def sparkline_value_color_map_apply_to(self) -> Optional[str]:
        """
        For the single stat view, whether to apply dyunamic color settings to 
        the displayed `TEXT` or `BACKGROUND`. Valid options are `TEXT` or `BACKGROUND`
        """
        return pulumi.get(self, "sparkline_value_color_map_apply_to")

    @property
    @pulumi.getter(name="sparklineValueColorMapColors")
    def sparkline_value_color_map_colors(self) -> Optional[Sequence[str]]:
        """
        For the single stat view, A list of colors that differing query values map to. 
        Must contain one more element than `sparkline_value_color_map_values_v2`. Values should be in `rgba(,,,,)`
        """
        return pulumi.get(self, "sparkline_value_color_map_colors")

    @property
    @pulumi.getter(name="sparklineValueColorMapValues")
    def sparkline_value_color_map_values(self) -> Optional[Sequence[int]]:
        """
        deprecated
        """
        return pulumi.get(self, "sparkline_value_color_map_values")

    @property
    @pulumi.getter(name="sparklineValueColorMapValuesV2s")
    def sparkline_value_color_map_values_v2s(self) -> Optional[Sequence[float]]:
        """
        For the single stat view, a list of boundaries for mapping different
        query values to colors.  Must contain one less element than `sparkline_value_color_map_colors`
        """
        return pulumi.get(self, "sparkline_value_color_map_values_v2s")

    @property
    @pulumi.getter(name="sparklineValueTextMapTexts")
    def sparkline_value_text_map_texts(self) -> Optional[Sequence[str]]:
        """
        For the single stat view, a list of display text values that different query
        values map to.  Must contain one more element than `sparkline_value_text_map_thresholds`
        """
        return pulumi.get(self, "sparkline_value_text_map_texts")

    @property
    @pulumi.getter(name="sparklineValueTextMapThresholds")
    def sparkline_value_text_map_thresholds(self) -> Optional[Sequence[float]]:
        """
        For the single stat view, a list of threshold boundaries for 
        mapping different query values to display text.  Must contain one less element than `sparkline_value_text_map_text`
        """
        return pulumi.get(self, "sparkline_value_text_map_thresholds")

    @property
    @pulumi.getter(name="stackType")
    def stack_type(self) -> Optional[str]:
        """
        Type of stacked chart (applicable only if chart type is `stacked`). `zero` (default) means
        stacked from y=0. `expand` means normalized from 0 to 1.  `wiggle` means minimize weighted changes. `silhouette` means to
        center the stream. Valid options are `zero`, `expand`, `wiggle`, `silhouette`, `bars`
        """
        return pulumi.get(self, "stack_type")

    @property
    @pulumi.getter(name="tagMode")
    def tag_mode(self) -> Optional[str]:
        """
        For the tabular view, which mode to use to determine which point tags to display.
        Valid options are `all`, `top`, or `custom`
        """
        return pulumi.get(self, "tag_mode")

    @property
    @pulumi.getter(name="timeBasedColoring")
    def time_based_coloring(self) -> Optional[bool]:
        """
        For x-y scatterplots, whether to color more recent points as darker than older points
        """
        return pulumi.get(self, "time_based_coloring")

    @property
    @pulumi.getter(name="windowSize")
    def window_size(self) -> Optional[int]:
        """
        Width, in minutes, of the time window to use for `last` windowing
        """
        return pulumi.get(self, "window_size")

    @property
    @pulumi.getter
    def windowing(self) -> Optional[str]:
        """
        For the tabular view, whether to use the full time window for the query or the last X minutes.
        Valid options are `full` or `last`
        """
        return pulumi.get(self, "windowing")

    @property
    @pulumi.getter
    def xmax(self) -> Optional[float]:
        """
        For x-y scatterplots, max value for the X-axis. Set to null for auto
        """
        return pulumi.get(self, "xmax")

    @property
    @pulumi.getter
    def xmin(self) -> Optional[float]:
        """
        For x-y scatterplots, min value for the X-axis. Set to null for auto
        """
        return pulumi.get(self, "xmin")

    @property
    @pulumi.getter(name="y0ScaleSiBy1024")
    def y0_scale_si_by1024(self) -> Optional[bool]:
        """
        Whether to scale numerical magnitude labels for left Y-axis by 1024 in the IEC/Binary manner (instead of by 1000 like SI)
        """
        return pulumi.get(self, "y0_scale_si_by1024")

    @property
    @pulumi.getter(name="y0UnitAutoscaling")
    def y0_unit_autoscaling(self) -> Optional[bool]:
        """
        Whether to automatically adjust magnitude labels and units for the left Y-axis to favor smaller magnitudes and larger units
        """
        return pulumi.get(self, "y0_unit_autoscaling")

    @property
    @pulumi.getter(name="y1ScaleSiBy1024")
    def y1_scale_si_by1024(self) -> Optional[bool]:
        """
        Whether to scale numerical magnitude labels for right Y-axis by 1024 in the IEC/Binary manner (instead of by 1000 like SI)
        """
        return pulumi.get(self, "y1_scale_si_by1024")

    @property
    @pulumi.getter(name="y1UnitAutoscaling")
    def y1_unit_autoscaling(self) -> Optional[bool]:
        """
        Whether to automatically adjust magnitude labels and units for the right Y-axis to favor smaller magnitudes and larger units
        """
        return pulumi.get(self, "y1_unit_autoscaling")

    @property
    @pulumi.getter(name="y1Units")
    def y1_units(self) -> Optional[str]:
        """
        For plots with multiple Y-axes, units for right side Y-axis
        """
        return pulumi.get(self, "y1_units")

    @property
    @pulumi.getter
    def y1max(self) -> Optional[float]:
        """
        For plots with multiple Y-axes, max value for the right side Y-axis. Set null for auto
        """
        return pulumi.get(self, "y1max")

    @property
    @pulumi.getter
    def y1min(self) -> Optional[float]:
        """
        For plots with multiple Y-axes, min value for the right side Y-axis. Set null for auto
        """
        return pulumi.get(self, "y1min")

    @property
    @pulumi.getter
    def ymax(self) -> Optional[float]:
        """
        For x-y scatterplots, max value for the Y-axis. Set to null for auto
        """
        return pulumi.get(self, "ymax")

    @property
    @pulumi.getter
    def ymin(self) -> Optional[float]:
        """
        For x-y scatterplots, min value for the Y-axis. Set to null for auto
        """
        return pulumi.get(self, "ymin")

    def _translate_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop


@pulumi.output_type
class DashboardSectionRowChartSource(dict):
    def __init__(__self__, *,
                 name: str,
                 query: str,
                 disabled: Optional[bool] = None,
                 query_builder_enabled: Optional[bool] = None,
                 scatter_plot_source: Optional[str] = None,
                 source_description: Optional[str] = None):
        """
        :param str name: Name of the source
        :param str query: Query expression to plot on the chart
        :param bool disabled: Whether the source is disabled
        :param bool query_builder_enabled: Whether oir not this source line should have the query builder enabled
        :param str scatter_plot_source: For scatter plots, does this query source the X-axis or the Y-axis, `X`, or `Y`.
        :param str source_description: A description for the purpose of this source
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "query", query)
        if disabled is not None:
            pulumi.set(__self__, "disabled", disabled)
        if query_builder_enabled is not None:
            pulumi.set(__self__, "query_builder_enabled", query_builder_enabled)
        if scatter_plot_source is not None:
            pulumi.set(__self__, "scatter_plot_source", scatter_plot_source)
        if source_description is not None:
            pulumi.set(__self__, "source_description", source_description)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the source
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def query(self) -> str:
        """
        Query expression to plot on the chart
        """
        return pulumi.get(self, "query")

    @property
    @pulumi.getter
    def disabled(self) -> Optional[bool]:
        """
        Whether the source is disabled
        """
        return pulumi.get(self, "disabled")

    @property
    @pulumi.getter(name="queryBuilderEnabled")
    def query_builder_enabled(self) -> Optional[bool]:
        """
        Whether oir not this source line should have the query builder enabled
        """
        return pulumi.get(self, "query_builder_enabled")

    @property
    @pulumi.getter(name="scatterPlotSource")
    def scatter_plot_source(self) -> Optional[str]:
        """
        For scatter plots, does this query source the X-axis or the Y-axis, `X`, or `Y`.
        """
        return pulumi.get(self, "scatter_plot_source")

    @property
    @pulumi.getter(name="sourceDescription")
    def source_description(self) -> Optional[str]:
        """
        A description for the purpose of this source
        """
        return pulumi.get(self, "source_description")

    def _translate_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from . import _utilities, _tables

__all__ = ['MaintenanceWindow']


class MaintenanceWindow(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 end_time_in_seconds: Optional[pulumi.Input[int]] = None,
                 host_tag_group_host_names_group_anded: Optional[pulumi.Input[bool]] = None,
                 reason: Optional[pulumi.Input[str]] = None,
                 relevant_customer_tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 relevant_host_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 relevant_host_tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 relevant_host_tags_anded: Optional[pulumi.Input[bool]] = None,
                 start_time_in_seconds: Optional[pulumi.Input[int]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Provides a Wavefront Maintenance Window Resource. This allows maintenance windows to be created, updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        basic = wavefront.MaintenanceWindow("basic",
            end_time_in_seconds=1601123456,
            reason="Routine maintenance for 2020",
            relevant_host_names=[
                "my_hostname",
                "my_other_hostname",
            ],
            start_time_in_seconds=1600123456,
            title="Routine maintenance")
        ```

        ## Import

        Maintenance windows can be imported using the `id`, e.g.

        ```sh
         $ pulumi import wavefront:index/maintenanceWindow:MaintenanceWindow basic 1600383357095
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] end_time_in_seconds: end time in seconds after 1 Jan 1970 GMT.
        :param pulumi.Input[bool] host_tag_group_host_names_group_anded: If true, a source/host must be in 'relevantHostNames' and have tags matching the specification formed by 'relevantHostTags' and 'relevantHostTagsAnded' in order for this maintenance window to apply. If false, a source/host must either be in 'relevantHostNames' or match 'relevantHostTags' and 'relevantHostTagsAnded'. Default: false
        :param pulumi.Input[str] reason: The reason for the maintenance window
        :param pulumi.Input[Sequence[pulumi.Input[str]]] relevant_customer_tags: List of alert tags whose matching alerts will be put into maintenance because of this maintenance window. At least one of relevant_customer_tags, relevant_host_tags, or relevant_host_names is required.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] relevant_host_names: List of source/host names that will be put into maintenance because of this maintenance window. At least one of relevant_customer_tags, relevant_host_tags, or relevant_host_names is required.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] relevant_host_tags: List of source/host tags whose matching sources/hosts will be put into maintenance because of this maintenance window. At least one of relevant_customer_tags, relevant_host_tags, or relevant_host_names is required.
        :param pulumi.Input[bool] relevant_host_tags_anded: Whether to AND source/host tags listed in relevantHostTags. If true, a source/host must contain all tags in order for the maintenance window to apply. If false, the tags are OR'ed, and a source/host must contain one of the tags. Default: false
        :param pulumi.Input[int] start_time_in_seconds: start time in seconds after 1 Jan 1970 GMT.
        :param pulumi.Input[str] title: The title of the maintenance window
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if end_time_in_seconds is None and not opts.urn:
                raise TypeError("Missing required property 'end_time_in_seconds'")
            __props__['end_time_in_seconds'] = end_time_in_seconds
            __props__['host_tag_group_host_names_group_anded'] = host_tag_group_host_names_group_anded
            if reason is None and not opts.urn:
                raise TypeError("Missing required property 'reason'")
            __props__['reason'] = reason
            __props__['relevant_customer_tags'] = relevant_customer_tags
            __props__['relevant_host_names'] = relevant_host_names
            __props__['relevant_host_tags'] = relevant_host_tags
            __props__['relevant_host_tags_anded'] = relevant_host_tags_anded
            if start_time_in_seconds is None and not opts.urn:
                raise TypeError("Missing required property 'start_time_in_seconds'")
            __props__['start_time_in_seconds'] = start_time_in_seconds
            if title is None and not opts.urn:
                raise TypeError("Missing required property 'title'")
            __props__['title'] = title
        super(MaintenanceWindow, __self__).__init__(
            'wavefront:index/maintenanceWindow:MaintenanceWindow',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            end_time_in_seconds: Optional[pulumi.Input[int]] = None,
            host_tag_group_host_names_group_anded: Optional[pulumi.Input[bool]] = None,
            reason: Optional[pulumi.Input[str]] = None,
            relevant_customer_tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            relevant_host_names: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            relevant_host_tags: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            relevant_host_tags_anded: Optional[pulumi.Input[bool]] = None,
            start_time_in_seconds: Optional[pulumi.Input[int]] = None,
            title: Optional[pulumi.Input[str]] = None) -> 'MaintenanceWindow':
        """
        Get an existing MaintenanceWindow resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] end_time_in_seconds: end time in seconds after 1 Jan 1970 GMT.
        :param pulumi.Input[bool] host_tag_group_host_names_group_anded: If true, a source/host must be in 'relevantHostNames' and have tags matching the specification formed by 'relevantHostTags' and 'relevantHostTagsAnded' in order for this maintenance window to apply. If false, a source/host must either be in 'relevantHostNames' or match 'relevantHostTags' and 'relevantHostTagsAnded'. Default: false
        :param pulumi.Input[str] reason: The reason for the maintenance window
        :param pulumi.Input[Sequence[pulumi.Input[str]]] relevant_customer_tags: List of alert tags whose matching alerts will be put into maintenance because of this maintenance window. At least one of relevant_customer_tags, relevant_host_tags, or relevant_host_names is required.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] relevant_host_names: List of source/host names that will be put into maintenance because of this maintenance window. At least one of relevant_customer_tags, relevant_host_tags, or relevant_host_names is required.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] relevant_host_tags: List of source/host tags whose matching sources/hosts will be put into maintenance because of this maintenance window. At least one of relevant_customer_tags, relevant_host_tags, or relevant_host_names is required.
        :param pulumi.Input[bool] relevant_host_tags_anded: Whether to AND source/host tags listed in relevantHostTags. If true, a source/host must contain all tags in order for the maintenance window to apply. If false, the tags are OR'ed, and a source/host must contain one of the tags. Default: false
        :param pulumi.Input[int] start_time_in_seconds: start time in seconds after 1 Jan 1970 GMT.
        :param pulumi.Input[str] title: The title of the maintenance window
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["end_time_in_seconds"] = end_time_in_seconds
        __props__["host_tag_group_host_names_group_anded"] = host_tag_group_host_names_group_anded
        __props__["reason"] = reason
        __props__["relevant_customer_tags"] = relevant_customer_tags
        __props__["relevant_host_names"] = relevant_host_names
        __props__["relevant_host_tags"] = relevant_host_tags
        __props__["relevant_host_tags_anded"] = relevant_host_tags_anded
        __props__["start_time_in_seconds"] = start_time_in_seconds
        __props__["title"] = title
        return MaintenanceWindow(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="endTimeInSeconds")
    def end_time_in_seconds(self) -> pulumi.Output[int]:
        """
        end time in seconds after 1 Jan 1970 GMT.
        """
        return pulumi.get(self, "end_time_in_seconds")

    @property
    @pulumi.getter(name="hostTagGroupHostNamesGroupAnded")
    def host_tag_group_host_names_group_anded(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, a source/host must be in 'relevantHostNames' and have tags matching the specification formed by 'relevantHostTags' and 'relevantHostTagsAnded' in order for this maintenance window to apply. If false, a source/host must either be in 'relevantHostNames' or match 'relevantHostTags' and 'relevantHostTagsAnded'. Default: false
        """
        return pulumi.get(self, "host_tag_group_host_names_group_anded")

    @property
    @pulumi.getter
    def reason(self) -> pulumi.Output[str]:
        """
        The reason for the maintenance window
        """
        return pulumi.get(self, "reason")

    @property
    @pulumi.getter(name="relevantCustomerTags")
    def relevant_customer_tags(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of alert tags whose matching alerts will be put into maintenance because of this maintenance window. At least one of relevant_customer_tags, relevant_host_tags, or relevant_host_names is required.
        """
        return pulumi.get(self, "relevant_customer_tags")

    @property
    @pulumi.getter(name="relevantHostNames")
    def relevant_host_names(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of source/host names that will be put into maintenance because of this maintenance window. At least one of relevant_customer_tags, relevant_host_tags, or relevant_host_names is required.
        """
        return pulumi.get(self, "relevant_host_names")

    @property
    @pulumi.getter(name="relevantHostTags")
    def relevant_host_tags(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of source/host tags whose matching sources/hosts will be put into maintenance because of this maintenance window. At least one of relevant_customer_tags, relevant_host_tags, or relevant_host_names is required.
        """
        return pulumi.get(self, "relevant_host_tags")

    @property
    @pulumi.getter(name="relevantHostTagsAnded")
    def relevant_host_tags_anded(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to AND source/host tags listed in relevantHostTags. If true, a source/host must contain all tags in order for the maintenance window to apply. If false, the tags are OR'ed, and a source/host must contain one of the tags. Default: false
        """
        return pulumi.get(self, "relevant_host_tags_anded")

    @property
    @pulumi.getter(name="startTimeInSeconds")
    def start_time_in_seconds(self) -> pulumi.Output[int]:
        """
        start time in seconds after 1 Jan 1970 GMT.
        """
        return pulumi.get(self, "start_time_in_seconds")

    @property
    @pulumi.getter
    def title(self) -> pulumi.Output[str]:
        """
        The title of the maintenance window
        """
        return pulumi.get(self, "title")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

